@@ -67,7 +67,7 @@ impl<'a> SARADC_START_FORCE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SARADC_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -131,7 +131,7 @@ impl<'a> SARADC_WORK_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 3)) | ((value as u32 & 0x03) << 3);
+        self.w.bits = (self.w.bits & !(3 << 3)) | ((value as u32 & 3) << 3);
         self.w
     }
 }
@@ -168,7 +168,7 @@ impl<'a> SARADC_SAR_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -205,7 +205,7 @@ impl<'a> SARADC_SAR_CLK_GATED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -323,7 +323,7 @@ impl<'a> SARADC_SAR1_PATT_P_CLEAR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -360,7 +360,7 @@ impl<'a> SARADC_SAR2_PATT_P_CLEAR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -397,7 +397,7 @@ impl<'a> SARADC_DATA_SAR_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -434,7 +434,7 @@ impl<'a> SARADC_DATA_TO_I2S_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -461,7 +461,7 @@ impl<'a> SARADC_XPD_SAR_FORCE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 27)) | ((value as u32 & 0x03) << 27);
+        self.w.bits = (self.w.bits & !(3 << 27)) | ((value as u32 & 3) << 27);
         self.w
     }
 }
@@ -488,7 +488,7 @@ impl<'a> SARADC_WAIT_ARB_CYCLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 30)) | ((value as u32 & 0x03) << 30);
+        self.w.bits = (self.w.bits & !(3 << 30)) | ((value as u32 & 3) << 30);
         self.w
     }
 }
@@ -496,27 +496,27 @@ impl R {
     #[doc = "Bit 0 - enable start saradc by sw"]
     #[inline(always)]
     pub fn saradc_start_force(&self) -> SARADC_START_FORCE_R {
-        SARADC_START_FORCE_R::new((self.bits & 0x01) != 0)
+        SARADC_START_FORCE_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - start saradc by sw"]
     #[inline(always)]
     pub fn saradc_start(&self) -> SARADC_START_R {
-        SARADC_START_R::new(((self.bits >> 1) & 0x01) != 0)
+        SARADC_START_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bits 3:4 - 0: single mode, 1: double mode, 2: alternate mode"]
     #[inline(always)]
     pub fn saradc_work_mode(&self) -> SARADC_WORK_MODE_R {
-        SARADC_WORK_MODE_R::new(((self.bits >> 3) & 0x03) as u8)
+        SARADC_WORK_MODE_R::new(((self.bits >> 3) & 3) as u8)
     }
     #[doc = "Bit 5 - 0: SAR1, 1: SAR2, only work for single SAR mode"]
     #[inline(always)]
     pub fn saradc_sar_sel(&self) -> SARADC_SAR_SEL_R {
-        SARADC_SAR_SEL_R::new(((self.bits >> 5) & 0x01) != 0)
+        SARADC_SAR_SEL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - enable SAR CLK gate when saradc idle"]
     #[inline(always)]
     pub fn saradc_sar_clk_gated(&self) -> SARADC_SAR_CLK_GATED_R {
-        SARADC_SAR_CLK_GATED_R::new(((self.bits >> 6) & 0x01) != 0)
+        SARADC_SAR_CLK_GATED_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bits 7:14 - SAR clock divider"]
     #[inline(always)]
@@ -536,32 +536,32 @@ impl R {
     #[doc = "Bit 23 - clear the pointer of pattern table for DIG ADC1 CTRL"]
     #[inline(always)]
     pub fn saradc_sar1_patt_p_clear(&self) -> SARADC_SAR1_PATT_P_CLEAR_R {
-        SARADC_SAR1_PATT_P_CLEAR_R::new(((self.bits >> 23) & 0x01) != 0)
+        SARADC_SAR1_PATT_P_CLEAR_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - clear the pointer of pattern table for DIG ADC2 CTRL"]
     #[inline(always)]
     pub fn saradc_sar2_patt_p_clear(&self) -> SARADC_SAR2_PATT_P_CLEAR_R {
-        SARADC_SAR2_PATT_P_CLEAR_R::new(((self.bits >> 24) & 0x01) != 0)
+        SARADC_SAR2_PATT_P_CLEAR_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - 1: sar_sel will be coded by the MSB of the 16-bit output data, in this case the resolution should not be larger than 11 bits."]
     #[inline(always)]
     pub fn saradc_data_sar_sel(&self) -> SARADC_DATA_SAR_SEL_R {
-        SARADC_DATA_SAR_SEL_R::new(((self.bits >> 25) & 0x01) != 0)
+        SARADC_DATA_SAR_SEL_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - 1: I2S input data is from SAR ADC (for DMA), 0: I2S input data is from GPIO matrix"]
     #[inline(always)]
     pub fn saradc_data_to_i2s(&self) -> SARADC_DATA_TO_I2S_R {
-        SARADC_DATA_TO_I2S_R::new(((self.bits >> 26) & 0x01) != 0)
+        SARADC_DATA_TO_I2S_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bits 27:28 - force option to xpd sar blocks"]
     #[inline(always)]
     pub fn saradc_xpd_sar_force(&self) -> SARADC_XPD_SAR_FORCE_R {
-        SARADC_XPD_SAR_FORCE_R::new(((self.bits >> 27) & 0x03) as u8)
+        SARADC_XPD_SAR_FORCE_R::new(((self.bits >> 27) & 3) as u8)
     }
     #[doc = "Bits 30:31 - wait arbit signal stable after sar_done"]
     #[inline(always)]
     pub fn saradc_wait_arb_cycle(&self) -> SARADC_WAIT_ARB_CYCLE_R {
-        SARADC_WAIT_ARB_CYCLE_R::new(((self.bits >> 30) & 0x03) as u8)
+        SARADC_WAIT_ARB_CYCLE_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
