@@ -67,7 +67,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN0_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN1_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN2_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN3_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN4_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN5_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN6_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> I2S_RX_TDM_PDM_CHAN7_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> I2S_RX_TDM_CHAN8_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> I2S_RX_TDM_CHAN9_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> I2S_RX_TDM_CHAN10_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> I2S_RX_TDM_CHAN11_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> I2S_RX_TDM_CHAN12_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> I2S_RX_TDM_CHAN13_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> I2S_RX_TDM_CHAN14_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> I2S_RX_TDM_CHAN15_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -657,82 +657,82 @@ impl R {
     #[doc = "Bit 0 - 1: Enable the valid data input of I2S RX TDM or PDM channel 0. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan0_en(&self) -> I2S_RX_TDM_PDM_CHAN0_EN_R {
-        I2S_RX_TDM_PDM_CHAN0_EN_R::new((self.bits & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN0_EN_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - 1: Enable the valid data input of I2S RX TDM or PDM channel 1. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan1_en(&self) -> I2S_RX_TDM_PDM_CHAN1_EN_R {
-        I2S_RX_TDM_PDM_CHAN1_EN_R::new(((self.bits >> 1) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN1_EN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - 1: Enable the valid data input of I2S RX TDM or PDM channel 2. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan2_en(&self) -> I2S_RX_TDM_PDM_CHAN2_EN_R {
-        I2S_RX_TDM_PDM_CHAN2_EN_R::new(((self.bits >> 2) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN2_EN_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - 1: Enable the valid data input of I2S RX TDM or PDM channel 3. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan3_en(&self) -> I2S_RX_TDM_PDM_CHAN3_EN_R {
-        I2S_RX_TDM_PDM_CHAN3_EN_R::new(((self.bits >> 3) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN3_EN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - 1: Enable the valid data input of I2S RX TDM or PDM channel 4. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan4_en(&self) -> I2S_RX_TDM_PDM_CHAN4_EN_R {
-        I2S_RX_TDM_PDM_CHAN4_EN_R::new(((self.bits >> 4) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN4_EN_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - 1: Enable the valid data input of I2S RX TDM or PDM channel 5. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan5_en(&self) -> I2S_RX_TDM_PDM_CHAN5_EN_R {
-        I2S_RX_TDM_PDM_CHAN5_EN_R::new(((self.bits >> 5) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN5_EN_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - 1: Enable the valid data input of I2S RX TDM or PDM channel 6. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan6_en(&self) -> I2S_RX_TDM_PDM_CHAN6_EN_R {
-        I2S_RX_TDM_PDM_CHAN6_EN_R::new(((self.bits >> 6) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN6_EN_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - 1: Enable the valid data input of I2S RX TDM or PDM channel 7. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_pdm_chan7_en(&self) -> I2S_RX_TDM_PDM_CHAN7_EN_R {
-        I2S_RX_TDM_PDM_CHAN7_EN_R::new(((self.bits >> 7) & 0x01) != 0)
+        I2S_RX_TDM_PDM_CHAN7_EN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - 1: Enable the valid data input of I2S RX TDM channel 8. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan8_en(&self) -> I2S_RX_TDM_CHAN8_EN_R {
-        I2S_RX_TDM_CHAN8_EN_R::new(((self.bits >> 8) & 0x01) != 0)
+        I2S_RX_TDM_CHAN8_EN_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - 1: Enable the valid data input of I2S RX TDM channel 9. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan9_en(&self) -> I2S_RX_TDM_CHAN9_EN_R {
-        I2S_RX_TDM_CHAN9_EN_R::new(((self.bits >> 9) & 0x01) != 0)
+        I2S_RX_TDM_CHAN9_EN_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - 1: Enable the valid data input of I2S RX TDM channel 10. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan10_en(&self) -> I2S_RX_TDM_CHAN10_EN_R {
-        I2S_RX_TDM_CHAN10_EN_R::new(((self.bits >> 10) & 0x01) != 0)
+        I2S_RX_TDM_CHAN10_EN_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - 1: Enable the valid data input of I2S RX TDM channel 11. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan11_en(&self) -> I2S_RX_TDM_CHAN11_EN_R {
-        I2S_RX_TDM_CHAN11_EN_R::new(((self.bits >> 11) & 0x01) != 0)
+        I2S_RX_TDM_CHAN11_EN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - 1: Enable the valid data input of I2S RX TDM channel 12. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan12_en(&self) -> I2S_RX_TDM_CHAN12_EN_R {
-        I2S_RX_TDM_CHAN12_EN_R::new(((self.bits >> 12) & 0x01) != 0)
+        I2S_RX_TDM_CHAN12_EN_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - 1: Enable the valid data input of I2S RX TDM channel 13. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan13_en(&self) -> I2S_RX_TDM_CHAN13_EN_R {
-        I2S_RX_TDM_CHAN13_EN_R::new(((self.bits >> 13) & 0x01) != 0)
+        I2S_RX_TDM_CHAN13_EN_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - 1: Enable the valid data input of I2S RX TDM channel 14. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan14_en(&self) -> I2S_RX_TDM_CHAN14_EN_R {
-        I2S_RX_TDM_CHAN14_EN_R::new(((self.bits >> 14) & 0x01) != 0)
+        I2S_RX_TDM_CHAN14_EN_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - 1: Enable the valid data input of I2S RX TDM channel 15. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn i2s_rx_tdm_chan15_en(&self) -> I2S_RX_TDM_CHAN15_EN_R {
-        I2S_RX_TDM_CHAN15_EN_R::new(((self.bits >> 15) & 0x01) != 0)
+        I2S_RX_TDM_CHAN15_EN_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bits 16:19 - The total channel number of I2S TX TDM mode."]
     #[inline(always)]
