@@ -52,7 +52,7 @@ impl<'a> I2S_TX_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -74,7 +74,7 @@ impl<'a> I2S_TX_FIFO_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -111,7 +111,7 @@ impl<'a> I2S_TX_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -148,7 +148,7 @@ impl<'a> I2S_TX_SLAVE_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -185,7 +185,7 @@ impl<'a> I2S_TX_MONO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -222,7 +222,7 @@ impl<'a> I2S_TX_CHAN_EQUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -259,7 +259,7 @@ impl<'a> I2S_TX_BIG_ENDIAN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -296,7 +296,7 @@ impl<'a> I2S_TX_UPDATE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -333,7 +333,7 @@ impl<'a> I2S_TX_MONO_FST_VLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -360,7 +360,7 @@ impl<'a> I2S_TX_PCM_CONF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
@@ -397,7 +397,7 @@ impl<'a> I2S_TX_PCM_BYPASS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -434,7 +434,7 @@ impl<'a> I2S_TX_STOP_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -471,7 +471,7 @@ impl<'a> I2S_TX_LEFT_ALIGN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -508,7 +508,7 @@ impl<'a> I2S_TX_24_FILL_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -545,7 +545,7 @@ impl<'a> I2S_TX_WS_IDLE_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -582,7 +582,7 @@ impl<'a> I2S_TX_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -619,7 +619,7 @@ impl<'a> I2S_TX_TDM_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -656,7 +656,7 @@ impl<'a> I2S_TX_PDM_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -683,7 +683,7 @@ impl<'a> I2S_TX_CHAN_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 24)) | ((value as u32 & 0x07) << 24);
+        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
         self.w
     }
 }
@@ -720,7 +720,7 @@ impl<'a> I2S_SIG_LOOPBACK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -728,92 +728,92 @@ impl R {
     #[doc = "Bit 2 - Set this bit to start transmitting data"]
     #[inline(always)]
     pub fn i2s_tx_start(&self) -> I2S_TX_START_R {
-        I2S_TX_START_R::new(((self.bits >> 2) & 0x01) != 0)
+        I2S_TX_START_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - Set this bit to enable slave transmitter mode"]
     #[inline(always)]
     pub fn i2s_tx_slave_mod(&self) -> I2S_TX_SLAVE_MOD_R {
-        I2S_TX_SLAVE_MOD_R::new(((self.bits >> 3) & 0x01) != 0)
+        I2S_TX_SLAVE_MOD_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 5 - Set this bit to enable transmitter in mono mode"]
     #[inline(always)]
     pub fn i2s_tx_mono(&self) -> I2S_TX_MONO_R {
-        I2S_TX_MONO_R::new(((self.bits >> 5) & 0x01) != 0)
+        I2S_TX_MONO_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - 1: The value of Left channel data is equal to the value of right channel data in I2S TX mono mode or TDM channel select mode. 0: The invalid channel data is reg_i2s_single_data in I2S TX mono mode or TDM channel select mode."]
     #[inline(always)]
     pub fn i2s_tx_chan_equal(&self) -> I2S_TX_CHAN_EQUAL_R {
-        I2S_TX_CHAN_EQUAL_R::new(((self.bits >> 6) & 0x01) != 0)
+        I2S_TX_CHAN_EQUAL_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - I2S Tx byte endian, 1: low addr value to high addr. 0: low addr with low addr value."]
     #[inline(always)]
     pub fn i2s_tx_big_endian(&self) -> I2S_TX_BIG_ENDIAN_R {
-        I2S_TX_BIG_ENDIAN_R::new(((self.bits >> 7) & 0x01) != 0)
+        I2S_TX_BIG_ENDIAN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Set 1 to update I2S TX registers from APB clock domain to I2S TX clock domain. This bit will be cleared by hardware after update register done."]
     #[inline(always)]
     pub fn i2s_tx_update(&self) -> I2S_TX_UPDATE_R {
-        I2S_TX_UPDATE_R::new(((self.bits >> 8) & 0x01) != 0)
+        I2S_TX_UPDATE_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - 1: The first channel data value is valid in I2S TX mono mode. 0: The second channel data value is valid in I2S TX mono mode."]
     #[inline(always)]
     pub fn i2s_tx_mono_fst_vld(&self) -> I2S_TX_MONO_FST_VLD_R {
-        I2S_TX_MONO_FST_VLD_R::new(((self.bits >> 9) & 0x01) != 0)
+        I2S_TX_MONO_FST_VLD_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bits 10:11 - I2S TX compress/decompress configuration bit. & 0 (atol): A-Law decompress, 1 (ltoa) : A-Law compress, 2 (utol) : u-Law decompress, 3 (ltou) : u-Law compress. &"]
     #[inline(always)]
     pub fn i2s_tx_pcm_conf(&self) -> I2S_TX_PCM_CONF_R {
-        I2S_TX_PCM_CONF_R::new(((self.bits >> 10) & 0x03) as u8)
+        I2S_TX_PCM_CONF_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bit 12 - Set this bit to bypass Compress/Decompress module for transmitted data."]
     #[inline(always)]
     pub fn i2s_tx_pcm_bypass(&self) -> I2S_TX_PCM_BYPASS_R {
-        I2S_TX_PCM_BYPASS_R::new(((self.bits >> 12) & 0x01) != 0)
+        I2S_TX_PCM_BYPASS_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Set this bit to stop disable output BCK signal and WS signal when tx FIFO is emtpy"]
     #[inline(always)]
     pub fn i2s_tx_stop_en(&self) -> I2S_TX_STOP_EN_R {
-        I2S_TX_STOP_EN_R::new(((self.bits >> 13) & 0x01) != 0)
+        I2S_TX_STOP_EN_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 15 - 1: I2S TX left alignment mode. 0: I2S TX right alignment mode."]
     #[inline(always)]
     pub fn i2s_tx_left_align(&self) -> I2S_TX_LEFT_ALIGN_R {
-        I2S_TX_LEFT_ALIGN_R::new(((self.bits >> 15) & 0x01) != 0)
+        I2S_TX_LEFT_ALIGN_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - 1: Sent 32 bits in 24 channel bits mode. 0: Sent 24 bits in 24 channel bits mode"]
     #[inline(always)]
     pub fn i2s_tx_24_fill_en(&self) -> I2S_TX_24_FILL_EN_R {
-        I2S_TX_24_FILL_EN_R::new(((self.bits >> 16) & 0x01) != 0)
+        I2S_TX_24_FILL_EN_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - 0: WS should be 0 when sending left channel data, and WS is 1in right channel. 1: WS should be 1 when sending left channel data, and WS is 0in right channel."]
     #[inline(always)]
     pub fn i2s_tx_ws_idle_pol(&self) -> I2S_TX_WS_IDLE_POL_R {
-        I2S_TX_WS_IDLE_POL_R::new(((self.bits >> 17) & 0x01) != 0)
+        I2S_TX_WS_IDLE_POL_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - I2S Tx bit endian. 1:small endian, the LSB is sent first. 0:big endian, the MSB is sent first."]
     #[inline(always)]
     pub fn i2s_tx_bit_order(&self) -> I2S_TX_BIT_ORDER_R {
-        I2S_TX_BIT_ORDER_R::new(((self.bits >> 18) & 0x01) != 0)
+        I2S_TX_BIT_ORDER_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - 1: Enable I2S TDM Tx mode . 0: Disable."]
     #[inline(always)]
     pub fn i2s_tx_tdm_en(&self) -> I2S_TX_TDM_EN_R {
-        I2S_TX_TDM_EN_R::new(((self.bits >> 19) & 0x01) != 0)
+        I2S_TX_TDM_EN_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - 1: Enable I2S PDM Tx mode . 0: Disable."]
     #[inline(always)]
     pub fn i2s_tx_pdm_en(&self) -> I2S_TX_PDM_EN_R {
-        I2S_TX_PDM_EN_R::new(((self.bits >> 20) & 0x01) != 0)
+        I2S_TX_PDM_EN_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bits 24:26 - I2S transmitter channel mode configuration bits."]
     #[inline(always)]
     pub fn i2s_tx_chan_mod(&self) -> I2S_TX_CHAN_MOD_R {
-        I2S_TX_CHAN_MOD_R::new(((self.bits >> 24) & 0x07) as u8)
+        I2S_TX_CHAN_MOD_R::new(((self.bits >> 24) & 7) as u8)
     }
     #[doc = "Bit 27 - Enable signal loop back mode with transmitter module and receiver module sharing the same WS and BCK signals."]
     #[inline(always)]
     pub fn i2s_sig_loopback(&self) -> I2S_SIG_LOOPBACK_R {
-        I2S_SIG_LOOPBACK_R::new(((self.bits >> 27) & 0x01) != 0)
+        I2S_SIG_LOOPBACK_R::new(((self.bits >> 27) & 1) != 0)
     }
 }
 impl W {
