@@ -67,7 +67,7 @@ impl<'a> CAM_STOP_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -94,7 +94,7 @@ impl<'a> CAM_VSYNC_FILTER_THRES_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 1)) | ((value as u32 & 0x07) << 1);
+        self.w.bits = (self.w.bits & !(7 << 1)) | ((value as u32 & 7) << 1);
         self.w
     }
 }
@@ -131,7 +131,7 @@ impl<'a> CAM_UPDATE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -176,7 +176,7 @@ impl<'a> CAM_BYTE_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -213,7 +213,7 @@ impl<'a> CAM_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -250,7 +250,7 @@ impl<'a> CAM_LINE_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -287,7 +287,7 @@ impl<'a> CAM_VS_EOF_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -395,7 +395,7 @@ impl<'a> CAM_CLK_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 29)) | ((value as u32 & 0x03) << 29);
+        self.w.bits = (self.w.bits & !(3 << 29)) | ((value as u32 & 3) << 29);
         self.w
     }
 }
@@ -403,17 +403,17 @@ impl R {
     #[doc = "Bit 0 - Camera stop enable signal, 1: camera stops when DMA Rx FIFO is full. 0: Not stop."]
     #[inline(always)]
     pub fn cam_stop_en(&self) -> CAM_STOP_EN_R {
-        CAM_STOP_EN_R::new((self.bits & 0x01) != 0)
+        CAM_STOP_EN_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bits 1:3 - Filter threshold value for CAM_VSYNC signal."]
     #[inline(always)]
     pub fn cam_vsync_filter_thres(&self) -> CAM_VSYNC_FILTER_THRES_R {
-        CAM_VSYNC_FILTER_THRES_R::new(((self.bits >> 1) & 0x07) as u8)
+        CAM_VSYNC_FILTER_THRES_R::new(((self.bits >> 1) & 7) as u8)
     }
     #[doc = "Bit 4 - 1: Update Camera registers, will be cleared by hardware. 0 : Not care."]
     #[inline(always)]
     pub fn cam_update(&self) -> CAM_UPDATE_R {
-        CAM_UPDATE_R::new(((self.bits >> 4) & 0x01) != 0)
+        CAM_UPDATE_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - 1: Change data bit order, change CAM_DATA_in\\[7:0\\]
  to CAM_DATA_in\\[0:7\\]
@@ -422,22 +422,22 @@ impl R {
  in two byte mode. 0: Not change."]
     #[inline(always)]
     pub fn cam_byte_order(&self) -> CAM_BYTE_ORDER_R {
-        CAM_BYTE_ORDER_R::new(((self.bits >> 5) & 0x01) != 0)
+        CAM_BYTE_ORDER_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - 1: invert data byte order, only valid in 2 byte mode. 0: Not change."]
     #[inline(always)]
     pub fn cam_bit_order(&self) -> CAM_BIT_ORDER_R {
-        CAM_BIT_ORDER_R::new(((self.bits >> 6) & 0x01) != 0)
+        CAM_BIT_ORDER_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - 1: Enable to generate CAM_HS_INT. 0: Disable."]
     #[inline(always)]
     pub fn cam_line_int_en(&self) -> CAM_LINE_INT_EN_R {
-        CAM_LINE_INT_EN_R::new(((self.bits >> 7) & 0x01) != 0)
+        CAM_LINE_INT_EN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - 1: CAM_VSYNC to generate in_suc_eof. 0: in_suc_eof is controlled by reg_cam_rec_data_cyclelen."]
     #[inline(always)]
     pub fn cam_vs_eof_en(&self) -> CAM_VS_EOF_EN_R {
-        CAM_VS_EOF_EN_R::new(((self.bits >> 8) & 0x01) != 0)
+        CAM_VS_EOF_EN_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bits 9:16 - Integral Camera clock divider value"]
     #[inline(always)]
@@ -457,7 +457,7 @@ impl R {
     #[doc = "Bits 29:30 - Select Camera module source clock. 0: no clock. 1: APLL. 2: CLK160. 3: no clock."]
     #[inline(always)]
     pub fn cam_clk_sel(&self) -> CAM_CLK_SEL_R {
-        CAM_CLK_SEL_R::new(((self.bits >> 29) & 0x03) as u8)
+        CAM_CLK_SEL_R::new(((self.bits >> 29) & 3) as u8)
     }
 }
 impl W {
