@@ -67,7 +67,7 @@ impl<'a> LCD_CONV_8BITS_DATA_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> LCD_CONV_TXTORX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -131,7 +131,7 @@ impl<'a> LCD_CONV_YUV2YUV_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
@@ -158,7 +158,7 @@ impl<'a> LCD_CONV_YUV_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
@@ -195,7 +195,7 @@ impl<'a> LCD_CONV_PROTOCOL_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -232,7 +232,7 @@ impl<'a> LCD_CONV_DATA_OUT_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -269,7 +269,7 @@ impl<'a> LCD_CONV_DATA_IN_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -306,7 +306,7 @@ impl<'a> LCD_CONV_MODE_8BITS_ON_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -343,7 +343,7 @@ impl<'a> LCD_CONV_TRANS_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -380,7 +380,7 @@ impl<'a> LCD_CONV_BYPASS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -388,52 +388,52 @@ impl R {
     #[doc = "Bit 20 - 1:invert every two 8bits input data. 2. disabled."]
     #[inline(always)]
     pub fn lcd_conv_8bits_data_inv(&self) -> LCD_CONV_8BITS_DATA_INV_R {
-        LCD_CONV_8BITS_DATA_INV_R::new(((self.bits >> 20) & 0x01) != 0)
+        LCD_CONV_8BITS_DATA_INV_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - 0: txtorx mode off. 1: txtorx mode on."]
     #[inline(always)]
     pub fn lcd_conv_txtorx(&self) -> LCD_CONV_TXTORX_R {
-        LCD_CONV_TXTORX_R::new(((self.bits >> 21) & 0x01) != 0)
+        LCD_CONV_TXTORX_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bits 22:23 - 0: to yuv422. 1: to yuv420. 2: to yuv411. 3: disabled. To enable yuv2yuv mode, trans_mode must be set to 1."]
     #[inline(always)]
     pub fn lcd_conv_yuv2yuv_mode(&self) -> LCD_CONV_YUV2YUV_MODE_R {
-        LCD_CONV_YUV2YUV_MODE_R::new(((self.bits >> 22) & 0x03) as u8)
+        LCD_CONV_YUV2YUV_MODE_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - 0: yuv422. 1: yuv420. 2: yuv411. When in yuv2yuv mode, yuv_mode decides the yuv mode of Data_in"]
     #[inline(always)]
     pub fn lcd_conv_yuv_mode(&self) -> LCD_CONV_YUV_MODE_R {
-        LCD_CONV_YUV_MODE_R::new(((self.bits >> 24) & 0x03) as u8)
+        LCD_CONV_YUV_MODE_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bit 26 - 0:BT601. 1:BT709."]
     #[inline(always)]
     pub fn lcd_conv_protocol_mode(&self) -> LCD_CONV_PROTOCOL_MODE_R {
-        LCD_CONV_PROTOCOL_MODE_R::new(((self.bits >> 26) & 0x01) != 0)
+        LCD_CONV_PROTOCOL_MODE_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - LIMIT or FULL mode of Data out. 0: limit. 1: full"]
     #[inline(always)]
     pub fn lcd_conv_data_out_mode(&self) -> LCD_CONV_DATA_OUT_MODE_R {
-        LCD_CONV_DATA_OUT_MODE_R::new(((self.bits >> 27) & 0x01) != 0)
+        LCD_CONV_DATA_OUT_MODE_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - LIMIT or FULL mode of Data in. 0: limit. 1: full"]
     #[inline(always)]
     pub fn lcd_conv_data_in_mode(&self) -> LCD_CONV_DATA_IN_MODE_R {
-        LCD_CONV_DATA_IN_MODE_R::new(((self.bits >> 28) & 0x01) != 0)
+        LCD_CONV_DATA_IN_MODE_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - 0: 16bits mode. 1: 8bits mode."]
     #[inline(always)]
     pub fn lcd_conv_mode_8bits_on(&self) -> LCD_CONV_MODE_8BITS_ON_R {
-        LCD_CONV_MODE_8BITS_ON_R::new(((self.bits >> 29) & 0x01) != 0)
+        LCD_CONV_MODE_8BITS_ON_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - 0: YUV to RGB. 1: RGB to YUV."]
     #[inline(always)]
     pub fn lcd_conv_trans_mode(&self) -> LCD_CONV_TRANS_MODE_R {
-        LCD_CONV_TRANS_MODE_R::new(((self.bits >> 30) & 0x01) != 0)
+        LCD_CONV_TRANS_MODE_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - 0: Bypass converter. 1: Enable converter."]
     #[inline(always)]
     pub fn lcd_conv_bypass(&self) -> LCD_CONV_BYPASS_R {
-        LCD_CONV_BYPASS_R::new(((self.bits >> 31) & 0x01) != 0)
+        LCD_CONV_BYPASS_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
