@@ -94,7 +94,7 @@ impl<'a> FILTER_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -131,7 +131,7 @@ impl<'a> THR_ZERO_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -168,7 +168,7 @@ impl<'a> THR_H_LIM_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -205,7 +205,7 @@ impl<'a> THR_L_LIM_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -242,7 +242,7 @@ impl<'a> THR_THRES0_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -279,7 +279,7 @@ impl<'a> THR_THRES1_EN_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -306,7 +306,7 @@ impl<'a> CH0_NEG_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -333,7 +333,7 @@ impl<'a> CH0_POS_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
@@ -360,7 +360,7 @@ impl<'a> CH0_HCTRL_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 20)) | ((value as u32 & 0x03) << 20);
+        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
         self.w
     }
 }
@@ -387,7 +387,7 @@ impl<'a> CH0_LCTRL_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
@@ -414,7 +414,7 @@ impl<'a> CH1_NEG_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
@@ -441,7 +441,7 @@ impl<'a> CH1_POS_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
@@ -468,7 +468,7 @@ impl<'a> CH1_HCTRL_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 28)) | ((value as u32 & 0x03) << 28);
+        self.w.bits = (self.w.bits & !(3 << 28)) | ((value as u32 & 3) << 28);
         self.w
     }
 }
@@ -495,7 +495,7 @@ impl<'a> CH1_LCTRL_MODE_U_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 30)) | ((value as u32 & 0x03) << 30);
+        self.w.bits = (self.w.bits & !(3 << 30)) | ((value as u32 & 3) << 30);
         self.w
     }
 }
@@ -508,72 +508,72 @@ impl R {
     #[doc = "Bit 10 - This is the enable bit for unit %s's input filter."]
     #[inline(always)]
     pub fn filter_en_u(&self) -> FILTER_EN_U_R {
-        FILTER_EN_U_R::new(((self.bits >> 10) & 0x01) != 0)
+        FILTER_EN_U_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - This is the enable bit for unit %s's zero comparator."]
     #[inline(always)]
     pub fn thr_zero_en_u(&self) -> THR_ZERO_EN_U_R {
-        THR_ZERO_EN_U_R::new(((self.bits >> 11) & 0x01) != 0)
+        THR_ZERO_EN_U_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - This is the enable bit for unit %s's thr_h_lim comparator."]
     #[inline(always)]
     pub fn thr_h_lim_en_u(&self) -> THR_H_LIM_EN_U_R {
-        THR_H_LIM_EN_U_R::new(((self.bits >> 12) & 0x01) != 0)
+        THR_H_LIM_EN_U_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - This is the enable bit for unit %s's thr_l_lim comparator."]
     #[inline(always)]
     pub fn thr_l_lim_en_u(&self) -> THR_L_LIM_EN_U_R {
-        THR_L_LIM_EN_U_R::new(((self.bits >> 13) & 0x01) != 0)
+        THR_L_LIM_EN_U_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - This is the enable bit for unit %s's thres0 comparator."]
     #[inline(always)]
     pub fn thr_thres0_en_u(&self) -> THR_THRES0_EN_U_R {
-        THR_THRES0_EN_U_R::new(((self.bits >> 14) & 0x01) != 0)
+        THR_THRES0_EN_U_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - This is the enable bit for unit %s's thres1 comparator."]
     #[inline(always)]
     pub fn thr_thres1_en_u(&self) -> THR_THRES1_EN_U_R {
-        THR_THRES1_EN_U_R::new(((self.bits >> 15) & 0x01) != 0)
+        THR_THRES1_EN_U_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bits 16:17 - This register sets the behavior when the signal input of channel 0 detects a negative edge. 1: Increase the counter;2: Decrease the counter;0, 3: No effect on counter"]
     #[inline(always)]
     pub fn ch0_neg_mode_u(&self) -> CH0_NEG_MODE_U_R {
-        CH0_NEG_MODE_U_R::new(((self.bits >> 16) & 0x03) as u8)
+        CH0_NEG_MODE_U_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - This register sets the behavior when the signal input of channel 0 detects a positive edge. 1: Increase the counter;2: Decrease the counter;0, 3: No effect on counter"]
     #[inline(always)]
     pub fn ch0_pos_mode_u(&self) -> CH0_POS_MODE_U_R {
-        CH0_POS_MODE_U_R::new(((self.bits >> 18) & 0x03) as u8)
+        CH0_POS_MODE_U_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:21 - This register configures how the CH%s_POS_MODE/CH%s_NEG_MODE settings will be modified when the control signal is high. 0: No modification;1: Invert behavior (increase -> decrease, decrease -> increase);2, 3: Inhibit counter modification"]
     #[inline(always)]
     pub fn ch0_hctrl_mode_u(&self) -> CH0_HCTRL_MODE_U_R {
-        CH0_HCTRL_MODE_U_R::new(((self.bits >> 20) & 0x03) as u8)
+        CH0_HCTRL_MODE_U_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 22:23 - This register configures how the CH%s_POS_MODE/CH%s_NEG_MODE settings will be modified when the control signal is low. 0: No modification;1: Invert behavior (increase -> decrease, decrease -> increase);2, 3: Inhibit counter modification"]
     #[inline(always)]
     pub fn ch0_lctrl_mode_u(&self) -> CH0_LCTRL_MODE_U_R {
-        CH0_LCTRL_MODE_U_R::new(((self.bits >> 22) & 0x03) as u8)
+        CH0_LCTRL_MODE_U_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - This register sets the behavior when the signal input of channel 1 detects a negative edge. 1: Increment the counter;2: Decrement the counter;0, 3: No effect on counter"]
     #[inline(always)]
     pub fn ch1_neg_mode_u(&self) -> CH1_NEG_MODE_U_R {
-        CH1_NEG_MODE_U_R::new(((self.bits >> 24) & 0x03) as u8)
+        CH1_NEG_MODE_U_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 26:27 - This register sets the behavior when the signal input of channel 1 detects a positive edge. 1: Increment the counter;2: Decrement the counter;0, 3: No effect on counter"]
     #[inline(always)]
     pub fn ch1_pos_mode_u(&self) -> CH1_POS_MODE_U_R {
-        CH1_POS_MODE_U_R::new(((self.bits >> 26) & 0x03) as u8)
+        CH1_POS_MODE_U_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - This register configures how the CH%s_POS_MODE/CH%s_NEG_MODE settings will be modified when the control signal is high. 0: No modification;1: Invert behavior (increase -> decrease, decrease -> increase);2, 3: Inhibit counter modification"]
     #[inline(always)]
     pub fn ch1_hctrl_mode_u(&self) -> CH1_HCTRL_MODE_U_R {
-        CH1_HCTRL_MODE_U_R::new(((self.bits >> 28) & 0x03) as u8)
+        CH1_HCTRL_MODE_U_R::new(((self.bits >> 28) & 3) as u8)
     }
     #[doc = "Bits 30:31 - This register configures how the CH%s_POS_MODE/CH%s_NEG_MODE settings will be modified when the control signal is low. 0: No modification;1: Invert behavior (increase -> decrease, decrease -> increase);2, 3: Inhibit counter modification"]
     #[inline(always)]
     pub fn ch1_lctrl_mode_u(&self) -> CH1_LCTRL_MODE_U_R {
-        CH1_LCTRL_MODE_U_R::new(((self.bits >> 30) & 0x03) as u8)
+        CH1_LCTRL_MODE_U_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
