@@ -67,7 +67,7 @@ impl<'a> TIMER0_STOP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> TIMER1_STOP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> TIMER2_STOP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> TIMER0_TEZ_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> TIMER1_TEZ_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> TIMER2_TEZ_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> TIMER0_TEP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> TIMER1_TEP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> TIMER2_TEP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> FAULT0_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> FAULT1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> FAULT2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> FAULT0_CLR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> FAULT1_CLR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> FAULT2_CLR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> CMPR0_TEA_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> CMPR1_TEA_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -696,7 +696,7 @@ impl<'a> CMPR2_TEA_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -733,7 +733,7 @@ impl<'a> CMPR0_TEB_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -770,7 +770,7 @@ impl<'a> CMPR1_TEB_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -807,7 +807,7 @@ impl<'a> CMPR2_TEB_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -844,7 +844,7 @@ impl<'a> TZ0_CBC_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -881,7 +881,7 @@ impl<'a> TZ1_CBC_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -918,7 +918,7 @@ impl<'a> TZ2_CBC_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -955,7 +955,7 @@ impl<'a> TZ0_OST_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -992,7 +992,7 @@ impl<'a> TZ1_OST_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -1029,7 +1029,7 @@ impl<'a> TZ2_OST_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -1066,7 +1066,7 @@ impl<'a> CAP0_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -1103,7 +1103,7 @@ impl<'a> CAP1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -1140,7 +1140,7 @@ impl<'a> CAP2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -1148,152 +1148,152 @@ impl R {
     #[doc = "Bit 0 - The enable bit for the interrupt triggered when the timer 0 stops."]
     #[inline(always)]
     pub fn timer0_stop_int_ena(&self) -> TIMER0_STOP_INT_ENA_R {
-        TIMER0_STOP_INT_ENA_R::new((self.bits & 0x01) != 0)
+        TIMER0_STOP_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - The enable bit for the interrupt triggered when the timer 1 stops."]
     #[inline(always)]
     pub fn timer1_stop_int_ena(&self) -> TIMER1_STOP_INT_ENA_R {
-        TIMER1_STOP_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        TIMER1_STOP_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - The enable bit for the interrupt triggered when the timer 2 stops."]
     #[inline(always)]
     pub fn timer2_stop_int_ena(&self) -> TIMER2_STOP_INT_ENA_R {
-        TIMER2_STOP_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        TIMER2_STOP_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - The enable bit for the interrupt triggered by a PWM timer 0 TEZ event."]
     #[inline(always)]
     pub fn timer0_tez_int_ena(&self) -> TIMER0_TEZ_INT_ENA_R {
-        TIMER0_TEZ_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        TIMER0_TEZ_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - The enable bit for the interrupt triggered by a PWM timer 1 TEZ event."]
     #[inline(always)]
     pub fn timer1_tez_int_ena(&self) -> TIMER1_TEZ_INT_ENA_R {
-        TIMER1_TEZ_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        TIMER1_TEZ_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - The enable bit for the interrupt triggered by a PWM timer 2 TEZ event."]
     #[inline(always)]
     pub fn timer2_tez_int_ena(&self) -> TIMER2_TEZ_INT_ENA_R {
-        TIMER2_TEZ_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        TIMER2_TEZ_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - The enable bit for the interrupt triggered by a PWM timer 0 TEP event."]
     #[inline(always)]
     pub fn timer0_tep_int_ena(&self) -> TIMER0_TEP_INT_ENA_R {
-        TIMER0_TEP_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        TIMER0_TEP_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - The enable bit for the interrupt triggered by a PWM timer 1 TEP event."]
     #[inline(always)]
     pub fn timer1_tep_int_ena(&self) -> TIMER1_TEP_INT_ENA_R {
-        TIMER1_TEP_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        TIMER1_TEP_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - The enable bit for the interrupt triggered by a PWM timer 2 TEP event."]
     #[inline(always)]
     pub fn timer2_tep_int_ena(&self) -> TIMER2_TEP_INT_ENA_R {
-        TIMER2_TEP_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        TIMER2_TEP_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - The enable bit for the interrupt triggered when event_f0 starts."]
     #[inline(always)]
     pub fn fault0_int_ena(&self) -> FAULT0_INT_ENA_R {
-        FAULT0_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        FAULT0_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - The enable bit for the interrupt triggered when event_f1 starts."]
     #[inline(always)]
     pub fn fault1_int_ena(&self) -> FAULT1_INT_ENA_R {
-        FAULT1_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        FAULT1_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - The enable bit for the interrupt triggered when event_f2 starts."]
     #[inline(always)]
     pub fn fault2_int_ena(&self) -> FAULT2_INT_ENA_R {
-        FAULT2_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        FAULT2_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - The enable bit for the interrupt triggered when event_f0 ends."]
     #[inline(always)]
     pub fn fault0_clr_int_ena(&self) -> FAULT0_CLR_INT_ENA_R {
-        FAULT0_CLR_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        FAULT0_CLR_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - The enable bit for the interrupt triggered when event_f1 ends."]
     #[inline(always)]
     pub fn fault1_clr_int_ena(&self) -> FAULT1_CLR_INT_ENA_R {
-        FAULT1_CLR_INT_ENA_R::new(((self.bits >> 13) & 0x01) != 0)
+        FAULT1_CLR_INT_ENA_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - The enable bit for the interrupt triggered when event_f2 ends."]
     #[inline(always)]
     pub fn fault2_clr_int_ena(&self) -> FAULT2_CLR_INT_ENA_R {
-        FAULT2_CLR_INT_ENA_R::new(((self.bits >> 14) & 0x01) != 0)
+        FAULT2_CLR_INT_ENA_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - The enable bit for the interrupt triggered by a PWM operator 0 TEA event"]
     #[inline(always)]
     pub fn cmpr0_tea_int_ena(&self) -> CMPR0_TEA_INT_ENA_R {
-        CMPR0_TEA_INT_ENA_R::new(((self.bits >> 15) & 0x01) != 0)
+        CMPR0_TEA_INT_ENA_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - The enable bit for the interrupt triggered by a PWM operator 1 TEA event"]
     #[inline(always)]
     pub fn cmpr1_tea_int_ena(&self) -> CMPR1_TEA_INT_ENA_R {
-        CMPR1_TEA_INT_ENA_R::new(((self.bits >> 16) & 0x01) != 0)
+        CMPR1_TEA_INT_ENA_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - The enable bit for the interrupt triggered by a PWM operator 2 TEA event"]
     #[inline(always)]
     pub fn cmpr2_tea_int_ena(&self) -> CMPR2_TEA_INT_ENA_R {
-        CMPR2_TEA_INT_ENA_R::new(((self.bits >> 17) & 0x01) != 0)
+        CMPR2_TEA_INT_ENA_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - The enable bit for the interrupt triggered by a PWM operator 0 TEB event"]
     #[inline(always)]
     pub fn cmpr0_teb_int_ena(&self) -> CMPR0_TEB_INT_ENA_R {
-        CMPR0_TEB_INT_ENA_R::new(((self.bits >> 18) & 0x01) != 0)
+        CMPR0_TEB_INT_ENA_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - The enable bit for the interrupt triggered by a PWM operator 1 TEB event"]
     #[inline(always)]
     pub fn cmpr1_teb_int_ena(&self) -> CMPR1_TEB_INT_ENA_R {
-        CMPR1_TEB_INT_ENA_R::new(((self.bits >> 19) & 0x01) != 0)
+        CMPR1_TEB_INT_ENA_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - The enable bit for the interrupt triggered by a PWM operator 2 TEB event"]
     #[inline(always)]
     pub fn cmpr2_teb_int_ena(&self) -> CMPR2_TEB_INT_ENA_R {
-        CMPR2_TEB_INT_ENA_R::new(((self.bits >> 20) & 0x01) != 0)
+        CMPR2_TEB_INT_ENA_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - The enable bit for the interrupt triggered by a cycle-by-cycle mode action on PWM0."]
     #[inline(always)]
     pub fn tz0_cbc_int_ena(&self) -> TZ0_CBC_INT_ENA_R {
-        TZ0_CBC_INT_ENA_R::new(((self.bits >> 21) & 0x01) != 0)
+        TZ0_CBC_INT_ENA_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - The enable bit for the interrupt triggered by a cycle-by-cycle mode action on PWM1."]
     #[inline(always)]
     pub fn tz1_cbc_int_ena(&self) -> TZ1_CBC_INT_ENA_R {
-        TZ1_CBC_INT_ENA_R::new(((self.bits >> 22) & 0x01) != 0)
+        TZ1_CBC_INT_ENA_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - The enable bit for the interrupt triggered by a cycle-by-cycle mode action on PWM2."]
     #[inline(always)]
     pub fn tz2_cbc_int_ena(&self) -> TZ2_CBC_INT_ENA_R {
-        TZ2_CBC_INT_ENA_R::new(((self.bits >> 23) & 0x01) != 0)
+        TZ2_CBC_INT_ENA_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - The enable bit for the interrupt triggered by a one-shot mode action on PWM0."]
     #[inline(always)]
     pub fn tz0_ost_int_ena(&self) -> TZ0_OST_INT_ENA_R {
-        TZ0_OST_INT_ENA_R::new(((self.bits >> 24) & 0x01) != 0)
+        TZ0_OST_INT_ENA_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - The enable bit for the interrupt triggered by a one-shot mode action on PWM1."]
     #[inline(always)]
     pub fn tz1_ost_int_ena(&self) -> TZ1_OST_INT_ENA_R {
-        TZ1_OST_INT_ENA_R::new(((self.bits >> 25) & 0x01) != 0)
+        TZ1_OST_INT_ENA_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - The enable bit for the interrupt triggered by a one-shot mode action on PWM2."]
     #[inline(always)]
     pub fn tz2_ost_int_ena(&self) -> TZ2_OST_INT_ENA_R {
-        TZ2_OST_INT_ENA_R::new(((self.bits >> 26) & 0x01) != 0)
+        TZ2_OST_INT_ENA_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - The enable bit for the interrupt triggered by capture on channel 0."]
     #[inline(always)]
     pub fn cap0_int_ena(&self) -> CAP0_INT_ENA_R {
-        CAP0_INT_ENA_R::new(((self.bits >> 27) & 0x01) != 0)
+        CAP0_INT_ENA_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - The enable bit for the interrupt triggered by capture on channel 1."]
     #[inline(always)]
     pub fn cap1_int_ena(&self) -> CAP1_INT_ENA_R {
-        CAP1_INT_ENA_R::new(((self.bits >> 28) & 0x01) != 0)
+        CAP1_INT_ENA_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - The enable bit for the interrupt triggered by capture on channel 2."]
     #[inline(always)]
     pub fn cap2_int_ena(&self) -> CAP2_INT_ENA_R {
-        CAP2_INT_ENA_R::new(((self.bits >> 29) & 0x01) != 0)
+        CAP2_INT_ENA_R::new(((self.bits >> 29) & 1) != 0)
     }
 }
 impl W {
