@@ -67,7 +67,7 @@ impl<'a> FORCE_OFF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> FORCE_ON_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> CLR_DG_PAD_AUTOHOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> DG_PAD_AUTOHOLD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> DG_PAD_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> DG_PAD_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> DG_PAD_FORCE_UNHOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> DG_PAD_FORCE_HOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> BT_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> BT_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> DG_PERI_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> DG_PERI_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> CPU_TOP_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> CPU_TOP_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> WIFI_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> WIFI_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> DG_WRAP_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -696,7 +696,7 @@ impl<'a> DG_WRAP_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -704,92 +704,92 @@ impl R {
     #[doc = "Bit 7 - No public"]
     #[inline(always)]
     pub fn force_off(&self) -> FORCE_OFF_R {
-        FORCE_OFF_R::new(((self.bits >> 7) & 0x01) != 0)
+        FORCE_OFF_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - No public"]
     #[inline(always)]
     pub fn force_on(&self) -> FORCE_ON_R {
-        FORCE_ON_R::new(((self.bits >> 8) & 0x01) != 0)
+        FORCE_ON_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - read only register to indicate digital pad auto-hold status"]
     #[inline(always)]
     pub fn dg_pad_autohold(&self) -> DG_PAD_AUTOHOLD_R {
-        DG_PAD_AUTOHOLD_R::new(((self.bits >> 9) & 0x01) != 0)
+        DG_PAD_AUTOHOLD_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 11 - digital pad enable auto-hold"]
     #[inline(always)]
     pub fn dg_pad_autohold_en(&self) -> DG_PAD_AUTOHOLD_EN_R {
-        DG_PAD_AUTOHOLD_EN_R::new(((self.bits >> 11) & 0x01) != 0)
+        DG_PAD_AUTOHOLD_EN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - digital pad force no ISO"]
     #[inline(always)]
     pub fn dg_pad_force_noiso(&self) -> DG_PAD_FORCE_NOISO_R {
-        DG_PAD_FORCE_NOISO_R::new(((self.bits >> 12) & 0x01) != 0)
+        DG_PAD_FORCE_NOISO_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - digital pad force ISO"]
     #[inline(always)]
     pub fn dg_pad_force_iso(&self) -> DG_PAD_FORCE_ISO_R {
-        DG_PAD_FORCE_ISO_R::new(((self.bits >> 13) & 0x01) != 0)
+        DG_PAD_FORCE_ISO_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - digital pad force un-hold"]
     #[inline(always)]
     pub fn dg_pad_force_unhold(&self) -> DG_PAD_FORCE_UNHOLD_R {
-        DG_PAD_FORCE_UNHOLD_R::new(((self.bits >> 14) & 0x01) != 0)
+        DG_PAD_FORCE_UNHOLD_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - digital pad force hold"]
     #[inline(always)]
     pub fn dg_pad_force_hold(&self) -> DG_PAD_FORCE_HOLD_R {
-        DG_PAD_FORCE_HOLD_R::new(((self.bits >> 15) & 0x01) != 0)
+        DG_PAD_FORCE_HOLD_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 22 - internal SRAM 2 force ISO"]
     #[inline(always)]
     pub fn bt_force_iso(&self) -> BT_FORCE_ISO_R {
-        BT_FORCE_ISO_R::new(((self.bits >> 22) & 0x01) != 0)
+        BT_FORCE_ISO_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - internal SRAM 2 force no ISO"]
     #[inline(always)]
     pub fn bt_force_noiso(&self) -> BT_FORCE_NOISO_R {
-        BT_FORCE_NOISO_R::new(((self.bits >> 23) & 0x01) != 0)
+        BT_FORCE_NOISO_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - internal SRAM 3 force ISO"]
     #[inline(always)]
     pub fn dg_peri_force_iso(&self) -> DG_PERI_FORCE_ISO_R {
-        DG_PERI_FORCE_ISO_R::new(((self.bits >> 24) & 0x01) != 0)
+        DG_PERI_FORCE_ISO_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - internal SRAM 3 force no ISO"]
     #[inline(always)]
     pub fn dg_peri_force_noiso(&self) -> DG_PERI_FORCE_NOISO_R {
-        DG_PERI_FORCE_NOISO_R::new(((self.bits >> 25) & 0x01) != 0)
+        DG_PERI_FORCE_NOISO_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - internal SRAM 4 force ISO"]
     #[inline(always)]
     pub fn cpu_top_force_iso(&self) -> CPU_TOP_FORCE_ISO_R {
-        CPU_TOP_FORCE_ISO_R::new(((self.bits >> 26) & 0x01) != 0)
+        CPU_TOP_FORCE_ISO_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - internal SRAM 4 force no ISO"]
     #[inline(always)]
     pub fn cpu_top_force_noiso(&self) -> CPU_TOP_FORCE_NOISO_R {
-        CPU_TOP_FORCE_NOISO_R::new(((self.bits >> 27) & 0x01) != 0)
+        CPU_TOP_FORCE_NOISO_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - wifi force ISO"]
     #[inline(always)]
     pub fn wifi_force_iso(&self) -> WIFI_FORCE_ISO_R {
-        WIFI_FORCE_ISO_R::new(((self.bits >> 28) & 0x01) != 0)
+        WIFI_FORCE_ISO_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - wifi force no ISO"]
     #[inline(always)]
     pub fn wifi_force_noiso(&self) -> WIFI_FORCE_NOISO_R {
-        WIFI_FORCE_NOISO_R::new(((self.bits >> 29) & 0x01) != 0)
+        WIFI_FORCE_NOISO_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - digital core force ISO"]
     #[inline(always)]
     pub fn dg_wrap_force_iso(&self) -> DG_WRAP_FORCE_ISO_R {
-        DG_WRAP_FORCE_ISO_R::new(((self.bits >> 30) & 0x01) != 0)
+        DG_WRAP_FORCE_ISO_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - digita core force no ISO"]
     #[inline(always)]
     pub fn dg_wrap_force_noiso(&self) -> DG_WRAP_FORCE_NOISO_R {
-        DG_WRAP_FORCE_NOISO_R::new(((self.bits >> 31) & 0x01) != 0)
+        DG_WRAP_FORCE_NOISO_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
