@@ -67,7 +67,7 @@ impl<'a> LSLP_MEM_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> LSLP_MEM_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> BT_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> BT_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> DG_PERI_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> DG_PERI_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> WIFI_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> WIFI_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> DG_WRAP_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> DG_WRAP_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> CPU_TOP_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> CPU_TOP_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> BT_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> DG_PERI_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> CPU_TOP_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> WIFI_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> DG_WRAP_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -667,87 +667,87 @@ impl R {
     #[doc = "Bit 3 - memories in digital core force PD in sleep"]
     #[inline(always)]
     pub fn lslp_mem_force_pd(&self) -> LSLP_MEM_FORCE_PD_R {
-        LSLP_MEM_FORCE_PD_R::new(((self.bits >> 3) & 0x01) != 0)
+        LSLP_MEM_FORCE_PD_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - memories in digital core force no PD in sleep"]
     #[inline(always)]
     pub fn lslp_mem_force_pu(&self) -> LSLP_MEM_FORCE_PU_R {
-        LSLP_MEM_FORCE_PU_R::new(((self.bits >> 4) & 0x01) != 0)
+        LSLP_MEM_FORCE_PU_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 11 - internal SRAM 2 force power down"]
     #[inline(always)]
     pub fn bt_force_pd(&self) -> BT_FORCE_PD_R {
-        BT_FORCE_PD_R::new(((self.bits >> 11) & 0x01) != 0)
+        BT_FORCE_PD_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - internal SRAM 2 force power up"]
     #[inline(always)]
     pub fn bt_force_pu(&self) -> BT_FORCE_PU_R {
-        BT_FORCE_PU_R::new(((self.bits >> 12) & 0x01) != 0)
+        BT_FORCE_PU_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - internal SRAM 3 force power down"]
     #[inline(always)]
     pub fn dg_peri_force_pd(&self) -> DG_PERI_FORCE_PD_R {
-        DG_PERI_FORCE_PD_R::new(((self.bits >> 13) & 0x01) != 0)
+        DG_PERI_FORCE_PD_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - internal SRAM 3 force power up"]
     #[inline(always)]
     pub fn dg_peri_force_pu(&self) -> DG_PERI_FORCE_PU_R {
-        DG_PERI_FORCE_PU_R::new(((self.bits >> 14) & 0x01) != 0)
+        DG_PERI_FORCE_PU_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 17 - wifi force power down"]
     #[inline(always)]
     pub fn wifi_force_pd(&self) -> WIFI_FORCE_PD_R {
-        WIFI_FORCE_PD_R::new(((self.bits >> 17) & 0x01) != 0)
+        WIFI_FORCE_PD_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - wifi force power up"]
     #[inline(always)]
     pub fn wifi_force_pu(&self) -> WIFI_FORCE_PU_R {
-        WIFI_FORCE_PU_R::new(((self.bits >> 18) & 0x01) != 0)
+        WIFI_FORCE_PU_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - digital core force power down"]
     #[inline(always)]
     pub fn dg_wrap_force_pd(&self) -> DG_WRAP_FORCE_PD_R {
-        DG_WRAP_FORCE_PD_R::new(((self.bits >> 19) & 0x01) != 0)
+        DG_WRAP_FORCE_PD_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - digital core force power up"]
     #[inline(always)]
     pub fn dg_wrap_force_pu(&self) -> DG_WRAP_FORCE_PU_R {
-        DG_WRAP_FORCE_PU_R::new(((self.bits >> 20) & 0x01) != 0)
+        DG_WRAP_FORCE_PU_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - digital dcdc force power down"]
     #[inline(always)]
     pub fn cpu_top_force_pd(&self) -> CPU_TOP_FORCE_PD_R {
-        CPU_TOP_FORCE_PD_R::new(((self.bits >> 21) & 0x01) != 0)
+        CPU_TOP_FORCE_PD_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - digital dcdc force power up"]
     #[inline(always)]
     pub fn cpu_top_force_pu(&self) -> CPU_TOP_FORCE_PU_R {
-        CPU_TOP_FORCE_PU_R::new(((self.bits >> 22) & 0x01) != 0)
+        CPU_TOP_FORCE_PU_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 27 - enable power down internal SRAM 2 in sleep"]
     #[inline(always)]
     pub fn bt_pd_en(&self) -> BT_PD_EN_R {
-        BT_PD_EN_R::new(((self.bits >> 27) & 0x01) != 0)
+        BT_PD_EN_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - enable power down internal SRAM 3 in sleep"]
     #[inline(always)]
     pub fn dg_peri_pd_en(&self) -> DG_PERI_PD_EN_R {
-        DG_PERI_PD_EN_R::new(((self.bits >> 28) & 0x01) != 0)
+        DG_PERI_PD_EN_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - enable power down internal SRAM 4 in sleep"]
     #[inline(always)]
     pub fn cpu_top_pd_en(&self) -> CPU_TOP_PD_EN_R {
-        CPU_TOP_PD_EN_R::new(((self.bits >> 29) & 0x01) != 0)
+        CPU_TOP_PD_EN_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - enable power down wifi in sleep"]
     #[inline(always)]
     pub fn wifi_pd_en(&self) -> WIFI_PD_EN_R {
-        WIFI_PD_EN_R::new(((self.bits >> 30) & 0x01) != 0)
+        WIFI_PD_EN_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - enable power down all digital logic"]
     #[inline(always)]
     pub fn dg_wrap_pd_en(&self) -> DG_WRAP_PD_EN_R {
-        DG_WRAP_PD_EN_R::new(((self.bits >> 31) & 0x01) != 0)
+        DG_WRAP_PD_EN_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
