@@ -67,7 +67,7 @@ impl<'a> SLP_WAKEUP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SLP_REJECT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SDIO_IDLE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> RTC_WDT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> RTC_TOUCH_SCAN_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> RTC_ULP_CP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> RTC_TOUCH_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> RTC_TOUCH_ACTIVE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> RTC_TOUCH_INACTIVE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> RTC_BROWN_OUT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> RTC_MAIN_TIMER_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> RTC_SARADC1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> RTC_TSENS_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> RTC_COCPU_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> RTC_SARADC2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> RTC_SWD_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> RTC_XTAL32K_DEAD_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -696,7 +696,7 @@ impl<'a> RTC_COCPU_TRAP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -733,7 +733,7 @@ impl<'a> RTC_TOUCH_TIMEOUT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -770,7 +770,7 @@ impl<'a> RTC_GLITCH_DET_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -807,7 +807,7 @@ impl<'a> RTC_TOUCH_APPROACH_LOOP_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -815,107 +815,107 @@ impl R {
     #[doc = "Bit 0 - enable sleep wakeup interrupt"]
     #[inline(always)]
     pub fn slp_wakeup_int_ena(&self) -> SLP_WAKEUP_INT_ENA_R {
-        SLP_WAKEUP_INT_ENA_R::new((self.bits & 0x01) != 0)
+        SLP_WAKEUP_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - enable sleep reject interrupt"]
     #[inline(always)]
     pub fn slp_reject_int_ena(&self) -> SLP_REJECT_INT_ENA_R {
-        SLP_REJECT_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        SLP_REJECT_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - enable SDIO idle interrupt"]
     #[inline(always)]
     pub fn sdio_idle_int_ena(&self) -> SDIO_IDLE_INT_ENA_R {
-        SDIO_IDLE_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        SDIO_IDLE_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - enable RTC WDT interrupt"]
     #[inline(always)]
     pub fn rtc_wdt_int_ena(&self) -> RTC_WDT_INT_ENA_R {
-        RTC_WDT_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        RTC_WDT_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - enable touch scan done interrupt"]
     #[inline(always)]
     pub fn rtc_touch_scan_done_int_ena(&self) -> RTC_TOUCH_SCAN_DONE_INT_ENA_R {
-        RTC_TOUCH_SCAN_DONE_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        RTC_TOUCH_SCAN_DONE_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - enable ULP-coprocessor interrupt"]
     #[inline(always)]
     pub fn rtc_ulp_cp_int_ena(&self) -> RTC_ULP_CP_INT_ENA_R {
-        RTC_ULP_CP_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        RTC_ULP_CP_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - enable touch done interrupt"]
     #[inline(always)]
     pub fn rtc_touch_done_int_ena(&self) -> RTC_TOUCH_DONE_INT_ENA_R {
-        RTC_TOUCH_DONE_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        RTC_TOUCH_DONE_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - enable touch active interrupt"]
     #[inline(always)]
     pub fn rtc_touch_active_int_ena(&self) -> RTC_TOUCH_ACTIVE_INT_ENA_R {
-        RTC_TOUCH_ACTIVE_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        RTC_TOUCH_ACTIVE_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - enable touch inactive interrupt"]
     #[inline(always)]
     pub fn rtc_touch_inactive_int_ena(&self) -> RTC_TOUCH_INACTIVE_INT_ENA_R {
-        RTC_TOUCH_INACTIVE_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        RTC_TOUCH_INACTIVE_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - enable brown out interrupt"]
     #[inline(always)]
     pub fn rtc_brown_out_int_ena(&self) -> RTC_BROWN_OUT_INT_ENA_R {
-        RTC_BROWN_OUT_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        RTC_BROWN_OUT_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - enable RTC main timer interrupt"]
     #[inline(always)]
     pub fn rtc_main_timer_int_ena(&self) -> RTC_MAIN_TIMER_INT_ENA_R {
-        RTC_MAIN_TIMER_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        RTC_MAIN_TIMER_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - enable saradc1 interrupt"]
     #[inline(always)]
     pub fn rtc_saradc1_int_ena(&self) -> RTC_SARADC1_INT_ENA_R {
-        RTC_SARADC1_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        RTC_SARADC1_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - enable tsens interrupt"]
     #[inline(always)]
     pub fn rtc_tsens_int_ena(&self) -> RTC_TSENS_INT_ENA_R {
-        RTC_TSENS_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        RTC_TSENS_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - enable riscV cocpu interrupt"]
     #[inline(always)]
     pub fn rtc_cocpu_int_ena(&self) -> RTC_COCPU_INT_ENA_R {
-        RTC_COCPU_INT_ENA_R::new(((self.bits >> 13) & 0x01) != 0)
+        RTC_COCPU_INT_ENA_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - enable saradc2 interrupt"]
     #[inline(always)]
     pub fn rtc_saradc2_int_ena(&self) -> RTC_SARADC2_INT_ENA_R {
-        RTC_SARADC2_INT_ENA_R::new(((self.bits >> 14) & 0x01) != 0)
+        RTC_SARADC2_INT_ENA_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - enable super watch dog interrupt"]
     #[inline(always)]
     pub fn rtc_swd_int_ena(&self) -> RTC_SWD_INT_ENA_R {
-        RTC_SWD_INT_ENA_R::new(((self.bits >> 15) & 0x01) != 0)
+        RTC_SWD_INT_ENA_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - enable xtal32k_dead interrupt"]
     #[inline(always)]
     pub fn rtc_xtal32k_dead_int_ena(&self) -> RTC_XTAL32K_DEAD_INT_ENA_R {
-        RTC_XTAL32K_DEAD_INT_ENA_R::new(((self.bits >> 16) & 0x01) != 0)
+        RTC_XTAL32K_DEAD_INT_ENA_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - enable cocpu trap interrupt"]
     #[inline(always)]
     pub fn rtc_cocpu_trap_int_ena(&self) -> RTC_COCPU_TRAP_INT_ENA_R {
-        RTC_COCPU_TRAP_INT_ENA_R::new(((self.bits >> 17) & 0x01) != 0)
+        RTC_COCPU_TRAP_INT_ENA_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - enable touch timeout interrupt"]
     #[inline(always)]
     pub fn rtc_touch_timeout_int_ena(&self) -> RTC_TOUCH_TIMEOUT_INT_ENA_R {
-        RTC_TOUCH_TIMEOUT_INT_ENA_R::new(((self.bits >> 18) & 0x01) != 0)
+        RTC_TOUCH_TIMEOUT_INT_ENA_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - enbale gitch det interrupt"]
     #[inline(always)]
     pub fn rtc_glitch_det_int_ena(&self) -> RTC_GLITCH_DET_INT_ENA_R {
-        RTC_GLITCH_DET_INT_ENA_R::new(((self.bits >> 19) & 0x01) != 0)
+        RTC_GLITCH_DET_INT_ENA_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - touch approach mode loop interrupt"]
     #[inline(always)]
     pub fn rtc_touch_approach_loop_done_int_ena(&self) -> RTC_TOUCH_APPROACH_LOOP_DONE_INT_ENA_R {
-        RTC_TOUCH_APPROACH_LOOP_DONE_INT_ENA_R::new(((self.bits >> 20) & 0x01) != 0)
+        RTC_TOUCH_APPROACH_LOOP_DONE_INT_ENA_R::new(((self.bits >> 20) & 1) != 0)
     }
 }
 impl W {
