@@ -57,7 +57,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_SPI_2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -84,7 +84,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_SPI_3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
@@ -111,7 +111,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_APB_CTRL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
@@ -138,7 +138,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_I2C_EXT1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -165,7 +165,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_SDIO_HOST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
@@ -192,7 +192,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_CAN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
@@ -219,7 +219,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_PWM1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
@@ -246,7 +246,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_I2S1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
@@ -273,7 +273,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_UART2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -300,7 +300,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_RWBT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
@@ -327,7 +327,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_WIFIMAC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
@@ -354,7 +354,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_PWR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 28)) | ((value as u32 & 0x03) << 28);
+        self.w.bits = (self.w.bits & !(3 << 28)) | ((value as u32 & 3) << 28);
         self.w
     }
 }
@@ -362,62 +362,62 @@ impl R {
     #[doc = "Bits 0:1 - BackUp access spi_2 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_spi_2(&self) -> BACKUP_BUS_PMS_CONSTRAIN_SPI_2_R {
-        BACKUP_BUS_PMS_CONSTRAIN_SPI_2_R::new((self.bits & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_SPI_2_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 2:3 - BackUp access spi_3 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_spi_3(&self) -> BACKUP_BUS_PMS_CONSTRAIN_SPI_3_R {
-        BACKUP_BUS_PMS_CONSTRAIN_SPI_3_R::new(((self.bits >> 2) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_SPI_3_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 4:5 - BackUp access apb_ctrl permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_apb_ctrl(&self) -> BACKUP_BUS_PMS_CONSTRAIN_APB_CTRL_R {
-        BACKUP_BUS_PMS_CONSTRAIN_APB_CTRL_R::new(((self.bits >> 4) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_APB_CTRL_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 6:7 - BackUp access i2c_ext1 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_i2c_ext1(&self) -> BACKUP_BUS_PMS_CONSTRAIN_I2C_EXT1_R {
-        BACKUP_BUS_PMS_CONSTRAIN_I2C_EXT1_R::new(((self.bits >> 6) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_I2C_EXT1_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 8:9 - BackUp access sdio_host permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_sdio_host(&self) -> BACKUP_BUS_PMS_CONSTRAIN_SDIO_HOST_R {
-        BACKUP_BUS_PMS_CONSTRAIN_SDIO_HOST_R::new(((self.bits >> 8) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_SDIO_HOST_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - BackUp access can permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_can(&self) -> BACKUP_BUS_PMS_CONSTRAIN_CAN_R {
-        BACKUP_BUS_PMS_CONSTRAIN_CAN_R::new(((self.bits >> 10) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_CAN_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - BackUp access pwm1 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_pwm1(&self) -> BACKUP_BUS_PMS_CONSTRAIN_PWM1_R {
-        BACKUP_BUS_PMS_CONSTRAIN_PWM1_R::new(((self.bits >> 12) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_PWM1_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - BackUp access i2s1 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_i2s1(&self) -> BACKUP_BUS_PMS_CONSTRAIN_I2S1_R {
-        BACKUP_BUS_PMS_CONSTRAIN_I2S1_R::new(((self.bits >> 14) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_I2S1_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:17 - BackUp access uart2 permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_uart2(&self) -> BACKUP_BUS_PMS_CONSTRAIN_UART2_R {
-        BACKUP_BUS_PMS_CONSTRAIN_UART2_R::new(((self.bits >> 16) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_UART2_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 22:23 - BackUp access rwbt permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_rwbt(&self) -> BACKUP_BUS_PMS_CONSTRAIN_RWBT_R {
-        BACKUP_BUS_PMS_CONSTRAIN_RWBT_R::new(((self.bits >> 22) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_RWBT_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 26:27 - BackUp access wifimac permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_wifimac(&self) -> BACKUP_BUS_PMS_CONSTRAIN_WIFIMAC_R {
-        BACKUP_BUS_PMS_CONSTRAIN_WIFIMAC_R::new(((self.bits >> 26) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_WIFIMAC_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - BackUp access pwr permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_pwr(&self) -> BACKUP_BUS_PMS_CONSTRAIN_PWR_R {
-        BACKUP_BUS_PMS_CONSTRAIN_PWR_R::new(((self.bits >> 28) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_PWR_R::new(((self.bits >> 28) & 3) as u8)
     }
 }
 impl W {
