@@ -57,7 +57,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_USB_DEVICE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -84,7 +84,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_USB_WRAP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
@@ -111,7 +111,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_PERI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
@@ -138,7 +138,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_DMA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -165,7 +165,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_APB_ADC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
@@ -192,7 +192,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_LCD_CAM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
@@ -219,7 +219,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_BT_PWR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
@@ -246,7 +246,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_USB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
@@ -273,7 +273,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_SYSTEM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -300,7 +300,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_SENSITIVE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
@@ -327,7 +327,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_INTERRUPT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 20)) | ((value as u32 & 0x03) << 20);
+        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
         self.w
     }
 }
@@ -354,7 +354,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_DMA_COPY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
@@ -381,7 +381,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_CACHE_CONFIG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
@@ -408,7 +408,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_AD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
@@ -435,7 +435,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 28)) | ((value as u32 & 0x03) << 28);
+        self.w.bits = (self.w.bits & !(3 << 28)) | ((value as u32 & 3) << 28);
         self.w
     }
 }
@@ -462,7 +462,7 @@ impl<'a> BACKUP_BUS_PMS_CONSTRAIN_WORLD_CONTROLLER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 30)) | ((value as u32 & 0x03) << 30);
+        self.w.bits = (self.w.bits & !(3 << 30)) | ((value as u32 & 3) << 30);
         self.w
     }
 }
@@ -470,84 +470,84 @@ impl R {
     #[doc = "Bits 0:1 - BackUp access usb_device permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_usb_device(&self) -> BACKUP_BUS_PMS_CONSTRAIN_USB_DEVICE_R {
-        BACKUP_BUS_PMS_CONSTRAIN_USB_DEVICE_R::new((self.bits & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_USB_DEVICE_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 2:3 - BackUp access usb_wrap permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_usb_wrap(&self) -> BACKUP_BUS_PMS_CONSTRAIN_USB_WRAP_R {
-        BACKUP_BUS_PMS_CONSTRAIN_USB_WRAP_R::new(((self.bits >> 2) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_USB_WRAP_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 4:5 - BackUp access crypto_peri permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_crypto_peri(&self) -> BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_PERI_R {
-        BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_PERI_R::new(((self.bits >> 4) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_PERI_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 6:7 - BackUp access crypto_dma permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_crypto_dma(&self) -> BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_DMA_R {
-        BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_DMA_R::new(((self.bits >> 6) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_CRYPTO_DMA_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 8:9 - BackUp access apb_adc permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_apb_adc(&self) -> BACKUP_BUS_PMS_CONSTRAIN_APB_ADC_R {
-        BACKUP_BUS_PMS_CONSTRAIN_APB_ADC_R::new(((self.bits >> 8) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_APB_ADC_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - BackUp access lcd_cam permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_lcd_cam(&self) -> BACKUP_BUS_PMS_CONSTRAIN_LCD_CAM_R {
-        BACKUP_BUS_PMS_CONSTRAIN_LCD_CAM_R::new(((self.bits >> 10) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_LCD_CAM_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - BackUp access bt_pwr permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_bt_pwr(&self) -> BACKUP_BUS_PMS_CONSTRAIN_BT_PWR_R {
-        BACKUP_BUS_PMS_CONSTRAIN_BT_PWR_R::new(((self.bits >> 12) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_BT_PWR_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - BackUp access usb permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_usb(&self) -> BACKUP_BUS_PMS_CONSTRAIN_USB_R {
-        BACKUP_BUS_PMS_CONSTRAIN_USB_R::new(((self.bits >> 14) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_USB_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:17 - BackUp access system permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_system(&self) -> BACKUP_BUS_PMS_CONSTRAIN_SYSTEM_R {
-        BACKUP_BUS_PMS_CONSTRAIN_SYSTEM_R::new(((self.bits >> 16) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_SYSTEM_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - BackUp access sensitive permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_sensitive(&self) -> BACKUP_BUS_PMS_CONSTRAIN_SENSITIVE_R {
-        BACKUP_BUS_PMS_CONSTRAIN_SENSITIVE_R::new(((self.bits >> 18) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_SENSITIVE_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:21 - BackUp access interrupt permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_interrupt(&self) -> BACKUP_BUS_PMS_CONSTRAIN_INTERRUPT_R {
-        BACKUP_BUS_PMS_CONSTRAIN_INTERRUPT_R::new(((self.bits >> 20) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_INTERRUPT_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 22:23 - BackUp access dma_copy permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_dma_copy(&self) -> BACKUP_BUS_PMS_CONSTRAIN_DMA_COPY_R {
-        BACKUP_BUS_PMS_CONSTRAIN_DMA_COPY_R::new(((self.bits >> 22) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_DMA_COPY_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - BackUp access cache_config permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_cache_config(&self) -> BACKUP_BUS_PMS_CONSTRAIN_CACHE_CONFIG_R {
-        BACKUP_BUS_PMS_CONSTRAIN_CACHE_CONFIG_R::new(((self.bits >> 24) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_CACHE_CONFIG_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 26:27 - BackUp access ad permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_ad(&self) -> BACKUP_BUS_PMS_CONSTRAIN_AD_R {
-        BACKUP_BUS_PMS_CONSTRAIN_AD_R::new(((self.bits >> 26) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_AD_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - BackUp access dio permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_dio(&self) -> BACKUP_BUS_PMS_CONSTRAIN_DIO_R {
-        BACKUP_BUS_PMS_CONSTRAIN_DIO_R::new(((self.bits >> 28) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_DIO_R::new(((self.bits >> 28) & 3) as u8)
     }
     #[doc = "Bits 30:31 - BackUp access world_controller permission."]
     #[inline(always)]
     pub fn backup_bus_pms_constrain_world_controller(
         &self,
     ) -> BACKUP_BUS_PMS_CONSTRAIN_WORLD_CONTROLLER_R {
-        BACKUP_BUS_PMS_CONSTRAIN_WORLD_CONTROLLER_R::new(((self.bits >> 30) & 0x03) as u8)
+        BACKUP_BUS_PMS_CONSTRAIN_WORLD_CONTROLLER_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
