@@ -57,7 +57,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_DEVICE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -84,7 +84,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_WRAP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
@@ -111,7 +111,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_PERI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
@@ -138,7 +138,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_DMA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -165,7 +165,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_APB_ADC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
@@ -192,7 +192,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_LCD_CAM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
@@ -219,7 +219,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_BT_PWR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
@@ -246,7 +246,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
@@ -273,7 +273,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SYSTEM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -300,7 +300,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SENSITIVE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
@@ -327,7 +327,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_INTERRUPT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 20)) | ((value as u32 & 0x03) << 20);
+        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
         self.w
     }
 }
@@ -354,7 +354,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DMA_COPY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 22)) | ((value as u32 & 0x03) << 22);
+        self.w.bits = (self.w.bits & !(3 << 22)) | ((value as u32 & 3) << 22);
         self.w
     }
 }
@@ -381,7 +381,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CACHE_CONFIG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
@@ -408,7 +408,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_AD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
@@ -435,7 +435,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 28)) | ((value as u32 & 0x03) << 28);
+        self.w.bits = (self.w.bits & !(3 << 28)) | ((value as u32 & 3) << 28);
         self.w
     }
 }
@@ -462,7 +462,7 @@ impl<'a> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_WORLD_CONTROLLER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 30)) | ((value as u32 & 0x03) << 30);
+        self.w.bits = (self.w.bits & !(3 << 30)) | ((value as u32 & 3) << 30);
         self.w
     }
 }
@@ -472,106 +472,106 @@ impl R {
     pub fn core_1_pif_pms_constrain_world_0_usb_device(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_DEVICE_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_DEVICE_R::new((self.bits & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_DEVICE_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 2:3 - Core1 access usb_wrap permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_usb_wrap(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_WRAP_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_WRAP_R::new(((self.bits >> 2) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_WRAP_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 4:5 - Core1 access crypto_peri permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_crypto_peri(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_PERI_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_PERI_R::new(((self.bits >> 4) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_PERI_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 6:7 - Core1 access crypto_dma permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_crypto_dma(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_DMA_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_DMA_R::new(((self.bits >> 6) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CRYPTO_DMA_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 8:9 - Core1 access apb_adc permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_apb_adc(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_APB_ADC_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_APB_ADC_R::new(((self.bits >> 8) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_APB_ADC_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - Core1 access lcd_cam permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_lcd_cam(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_LCD_CAM_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_LCD_CAM_R::new(((self.bits >> 10) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_LCD_CAM_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - Core1 access bt_pwr permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_bt_pwr(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_BT_PWR_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_BT_PWR_R::new(((self.bits >> 12) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_BT_PWR_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - Core1 access usb permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_usb(&self) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_R::new(((self.bits >> 14) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_USB_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:17 - Core1 access system permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_system(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SYSTEM_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SYSTEM_R::new(((self.bits >> 16) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SYSTEM_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - Core1 access sensitive permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_sensitive(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SENSITIVE_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SENSITIVE_R::new(((self.bits >> 18) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_SENSITIVE_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:21 - Core1 access interrupt permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_interrupt(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_INTERRUPT_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_INTERRUPT_R::new(((self.bits >> 20) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_INTERRUPT_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 22:23 - Core1 access dma_copy permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_dma_copy(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DMA_COPY_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DMA_COPY_R::new(((self.bits >> 22) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DMA_COPY_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - Core1 access cache_config permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_cache_config(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CACHE_CONFIG_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CACHE_CONFIG_R::new(((self.bits >> 24) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_CACHE_CONFIG_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 26:27 - Core1 access ad permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_ad(&self) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_AD_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_AD_R::new(((self.bits >> 26) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_AD_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - Core1 access dio permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_dio(&self) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DIO_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DIO_R::new(((self.bits >> 28) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_DIO_R::new(((self.bits >> 28) & 3) as u8)
     }
     #[doc = "Bits 30:31 - Core1 access world_controller permission in world0."]
     #[inline(always)]
     pub fn core_1_pif_pms_constrain_world_0_world_controller(
         &self,
     ) -> CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_WORLD_CONTROLLER_R {
-        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_WORLD_CONTROLLER_R::new(((self.bits >> 30) & 0x03) as u8)
+        CORE_1_PIF_PMS_CONSTRAIN_WORLD_0_WORLD_CONTROLLER_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
