@@ -34,7 +34,7 @@ impl From<crate::W<DDR_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_EN` reader - 1: in DDR mode, 0: in SDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_EN` reader - 1: in ddr mode, 0 in sdr mode"]
 pub struct SPI_FMEM_DDR_EN_R(crate::FieldReader<bool, bool>);
 impl SPI_FMEM_DDR_EN_R {
     #[inline(always)]
@@ -49,7 +49,7 @@ impl core::ops::Deref for SPI_FMEM_DDR_EN_R {
         &self.0
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_EN` writer - 1: in DDR mode, 0: in SDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_EN` writer - 1: in ddr mode, 0 in sdr mode"]
 pub struct SPI_FMEM_DDR_EN_W<'a> {
     w: &'a mut W,
 }
@@ -67,11 +67,11 @@ impl<'a> SPI_FMEM_DDR_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
-#[doc = "Field `SPI_FMEM_VAR_DUMMY` reader - Set the bit to enable variable dummy cycle in DDRmode."]
+#[doc = "Field `SPI_FMEM_VAR_DUMMY` reader - Set the bit to enable variable dummy cycle in DDR mode."]
 pub struct SPI_FMEM_VAR_DUMMY_R(crate::FieldReader<bool, bool>);
 impl SPI_FMEM_VAR_DUMMY_R {
     #[inline(always)]
@@ -86,7 +86,7 @@ impl core::ops::Deref for SPI_FMEM_VAR_DUMMY_R {
         &self.0
     }
 }
-#[doc = "Field `SPI_FMEM_VAR_DUMMY` writer - Set the bit to enable variable dummy cycle in DDRmode."]
+#[doc = "Field `SPI_FMEM_VAR_DUMMY` writer - Set the bit to enable variable dummy cycle in DDR mode."]
 pub struct SPI_FMEM_VAR_DUMMY_W<'a> {
     w: &'a mut W,
 }
@@ -104,7 +104,7 @@ impl<'a> SPI_FMEM_VAR_DUMMY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -141,11 +141,11 @@ impl<'a> SPI_FMEM_DDR_RDAT_SWP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_WDAT_SWP` reader - Set the bit to reorder TX data of the word in DDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_WDAT_SWP` reader - Set the bit to swap TX data of a word in DDR mode."]
 pub struct SPI_FMEM_DDR_WDAT_SWP_R(crate::FieldReader<bool, bool>);
 impl SPI_FMEM_DDR_WDAT_SWP_R {
     #[inline(always)]
@@ -160,7 +160,7 @@ impl core::ops::Deref for SPI_FMEM_DDR_WDAT_SWP_R {
         &self.0
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_WDAT_SWP` writer - Set the bit to reorder TX data of the word in DDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_WDAT_SWP` writer - Set the bit to swap TX data of a word in DDR mode."]
 pub struct SPI_FMEM_DDR_WDAT_SWP_W<'a> {
     w: &'a mut W,
 }
@@ -178,11 +178,11 @@ impl<'a> SPI_FMEM_DDR_WDAT_SWP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_CMD_DIS` reader - the bit is used to disable dual edge in command phase when DDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_CMD_DIS` reader - the bit is used to disable dual edge in CMD phase when ddr mode."]
 pub struct SPI_FMEM_DDR_CMD_DIS_R(crate::FieldReader<bool, bool>);
 impl SPI_FMEM_DDR_CMD_DIS_R {
     #[inline(always)]
@@ -197,7 +197,7 @@ impl core::ops::Deref for SPI_FMEM_DDR_CMD_DIS_R {
         &self.0
     }
 }
-#[doc = "Field `SPI_FMEM_DDR_CMD_DIS` writer - the bit is used to disable dual edge in command phase when DDR mode."]
+#[doc = "Field `SPI_FMEM_DDR_CMD_DIS` writer - the bit is used to disable dual edge in CMD phase when ddr mode."]
 pub struct SPI_FMEM_DDR_CMD_DIS_W<'a> {
     w: &'a mut W,
 }
@@ -215,7 +215,7 @@ impl<'a> SPI_FMEM_DDR_CMD_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -246,6 +246,80 @@ impl<'a> SPI_FMEM_OUTMINBYTELEN_W<'a> {
         self.w
     }
 }
+#[doc = "Field `SPI_FMEM_TX_DDR_MSK_EN` reader - Set this bit to mask the first or the last byte in MSPI ECC DDR write mode, when accesses to flash."]
+pub struct SPI_FMEM_TX_DDR_MSK_EN_R(crate::FieldReader<bool, bool>);
+impl SPI_FMEM_TX_DDR_MSK_EN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        SPI_FMEM_TX_DDR_MSK_EN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SPI_FMEM_TX_DDR_MSK_EN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SPI_FMEM_TX_DDR_MSK_EN` writer - Set this bit to mask the first or the last byte in MSPI ECC DDR write mode, when accesses to flash."]
+pub struct SPI_FMEM_TX_DDR_MSK_EN_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> SPI_FMEM_TX_DDR_MSK_EN_W<'a> {
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
+        self.w
+    }
+}
+#[doc = "Field `SPI_FMEM_RX_DDR_MSK_EN` reader - Set this bit to mask the first or the last byte in MSPI ECC DDR read mode, when accesses to flash."]
+pub struct SPI_FMEM_RX_DDR_MSK_EN_R(crate::FieldReader<bool, bool>);
+impl SPI_FMEM_RX_DDR_MSK_EN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        SPI_FMEM_RX_DDR_MSK_EN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SPI_FMEM_RX_DDR_MSK_EN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SPI_FMEM_RX_DDR_MSK_EN` writer - Set this bit to mask the first or the last byte in MSPI ECC DDR read mode, when accesses to flash."]
+pub struct SPI_FMEM_RX_DDR_MSK_EN_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> SPI_FMEM_RX_DDR_MSK_EN_W<'a> {
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
+        self.w
+    }
+}
 #[doc = "Field `SPI_FMEM_USR_DDR_DQS_THD` reader - The delay number of data strobe which from memory based on SPI_CLK."]
 pub struct SPI_FMEM_USR_DDR_DQS_THD_R(crate::FieldReader<u8, u8>);
 impl SPI_FMEM_USR_DDR_DQS_THD_R {
@@ -306,7 +380,7 @@ impl<'a> SPI_FMEM_DDR_DQS_LOOP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -343,7 +417,7 @@ impl<'a> SPI_FMEM_DDR_DQS_LOOP_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -380,7 +454,7 @@ impl<'a> SPI_FMEM_CLK_DIFF_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -417,7 +491,7 @@ impl<'a> SPI_FMEM_HYPERBUS_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -454,11 +528,11 @@ impl<'a> SPI_FMEM_DQS_CA_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
-#[doc = "Field `SPI_FMEM_HYPERBUS_DUMMY_2X` reader - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses flash or SPI1 accesses flash or sram."]
+#[doc = "Field `SPI_FMEM_HYPERBUS_DUMMY_2X` reader - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses to flash or SPI1 accesses flash or sram."]
 pub struct SPI_FMEM_HYPERBUS_DUMMY_2X_R(crate::FieldReader<bool, bool>);
 impl SPI_FMEM_HYPERBUS_DUMMY_2X_R {
     #[inline(always)]
@@ -473,7 +547,7 @@ impl core::ops::Deref for SPI_FMEM_HYPERBUS_DUMMY_2X_R {
         &self.0
     }
 }
-#[doc = "Field `SPI_FMEM_HYPERBUS_DUMMY_2X` writer - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses flash or SPI1 accesses flash or sram."]
+#[doc = "Field `SPI_FMEM_HYPERBUS_DUMMY_2X` writer - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses to flash or SPI1 accesses flash or sram."]
 pub struct SPI_FMEM_HYPERBUS_DUMMY_2X_W<'a> {
     w: &'a mut W,
 }
@@ -491,7 +565,7 @@ impl<'a> SPI_FMEM_HYPERBUS_DUMMY_2X_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -528,7 +602,7 @@ impl<'a> SPI_FMEM_CLK_DIFF_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -571,7 +645,7 @@ impl<'a> SPI_FMEM_OCTA_RAM_ADDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -614,41 +688,51 @@ impl<'a> SPI_FMEM_HYPERBUS_CA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 impl R {
-    #[doc = "Bit 0 - 1: in DDR mode, 0: in SDR mode."]
+    #[doc = "Bit 0 - 1: in ddr mode, 0 in sdr mode"]
     #[inline(always)]
     pub fn spi_fmem_ddr_en(&self) -> SPI_FMEM_DDR_EN_R {
-        SPI_FMEM_DDR_EN_R::new((self.bits & 0x01) != 0)
+        SPI_FMEM_DDR_EN_R::new((self.bits & 1) != 0)
     }
-    #[doc = "Bit 1 - Set the bit to enable variable dummy cycle in DDRmode."]
+    #[doc = "Bit 1 - Set the bit to enable variable dummy cycle in DDR mode."]
     #[inline(always)]
     pub fn spi_fmem_var_dummy(&self) -> SPI_FMEM_VAR_DUMMY_R {
-        SPI_FMEM_VAR_DUMMY_R::new(((self.bits >> 1) & 0x01) != 0)
+        SPI_FMEM_VAR_DUMMY_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - Set the bit to reorder RX data of the word in DDR mode."]
     #[inline(always)]
     pub fn spi_fmem_ddr_rdat_swp(&self) -> SPI_FMEM_DDR_RDAT_SWP_R {
-        SPI_FMEM_DDR_RDAT_SWP_R::new(((self.bits >> 2) & 0x01) != 0)
+        SPI_FMEM_DDR_RDAT_SWP_R::new(((self.bits >> 2) & 1) != 0)
     }
-    #[doc = "Bit 3 - Set the bit to reorder TX data of the word in DDR mode."]
+    #[doc = "Bit 3 - Set the bit to swap TX data of a word in DDR mode."]
     #[inline(always)]
     pub fn spi_fmem_ddr_wdat_swp(&self) -> SPI_FMEM_DDR_WDAT_SWP_R {
-        SPI_FMEM_DDR_WDAT_SWP_R::new(((self.bits >> 3) & 0x01) != 0)
+        SPI_FMEM_DDR_WDAT_SWP_R::new(((self.bits >> 3) & 1) != 0)
     }
-    #[doc = "Bit 4 - the bit is used to disable dual edge in command phase when DDR mode."]
+    #[doc = "Bit 4 - the bit is used to disable dual edge in CMD phase when ddr mode."]
     #[inline(always)]
     pub fn spi_fmem_ddr_cmd_dis(&self) -> SPI_FMEM_DDR_CMD_DIS_R {
-        SPI_FMEM_DDR_CMD_DIS_R::new(((self.bits >> 4) & 0x01) != 0)
+        SPI_FMEM_DDR_CMD_DIS_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bits 5:11 - It is the minimum output data length in the panda device."]
     #[inline(always)]
     pub fn spi_fmem_outminbytelen(&self) -> SPI_FMEM_OUTMINBYTELEN_R {
         SPI_FMEM_OUTMINBYTELEN_R::new(((self.bits >> 5) & 0x7f) as u8)
     }
+    #[doc = "Bit 12 - Set this bit to mask the first or the last byte in MSPI ECC DDR write mode, when accesses to flash."]
+    #[inline(always)]
+    pub fn spi_fmem_tx_ddr_msk_en(&self) -> SPI_FMEM_TX_DDR_MSK_EN_R {
+        SPI_FMEM_TX_DDR_MSK_EN_R::new(((self.bits >> 12) & 1) != 0)
+    }
+    #[doc = "Bit 13 - Set this bit to mask the first or the last byte in MSPI ECC DDR read mode, when accesses to flash."]
+    #[inline(always)]
+    pub fn spi_fmem_rx_ddr_msk_en(&self) -> SPI_FMEM_RX_DDR_MSK_EN_R {
+        SPI_FMEM_RX_DDR_MSK_EN_R::new(((self.bits >> 13) & 1) != 0)
+    }
     #[doc = "Bits 14:20 - The delay number of data strobe which from memory based on SPI_CLK."]
     #[inline(always)]
     pub fn spi_fmem_usr_ddr_dqs_thd(&self) -> SPI_FMEM_USR_DDR_DQS_THD_R {
@@ -657,37 +741,37 @@ impl R {
     #[doc = "Bit 21 - 1: Use internal signal as data strobe, the strobe can not be delayed by input timing module. 0: Use input SPI_DQS signal from PAD as data strobe, the strobe can be delayed by input timing module"]
     #[inline(always)]
     pub fn spi_fmem_ddr_dqs_loop(&self) -> SPI_FMEM_DDR_DQS_LOOP_R {
-        SPI_FMEM_DDR_DQS_LOOP_R::new(((self.bits >> 21) & 0x01) != 0)
+        SPI_FMEM_DDR_DQS_LOOP_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - When SPI_FMEM_DDR_DQS_LOOP and SPI_FMEM_DDR_EN are set, 1: Use internal SPI_CLK as data strobe. 0: Use internal ~SPI_CLK as data strobe. Otherwise this bit is not active."]
     #[inline(always)]
     pub fn spi_fmem_ddr_dqs_loop_mode(&self) -> SPI_FMEM_DDR_DQS_LOOP_MODE_R {
-        SPI_FMEM_DDR_DQS_LOOP_MODE_R::new(((self.bits >> 22) & 0x01) != 0)
+        SPI_FMEM_DDR_DQS_LOOP_MODE_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 24 - Set this bit to enable the differential SPI_CLK#."]
     #[inline(always)]
     pub fn spi_fmem_clk_diff_en(&self) -> SPI_FMEM_CLK_DIFF_EN_R {
-        SPI_FMEM_CLK_DIFF_EN_R::new(((self.bits >> 24) & 0x01) != 0)
+        SPI_FMEM_CLK_DIFF_EN_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - Set this bit to enable the SPI HyperBus mode."]
     #[inline(always)]
     pub fn spi_fmem_hyperbus_mode(&self) -> SPI_FMEM_HYPERBUS_MODE_R {
-        SPI_FMEM_HYPERBUS_MODE_R::new(((self.bits >> 25) & 0x01) != 0)
+        SPI_FMEM_HYPERBUS_MODE_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - Set this bit to enable the input of SPI_DQS signal in SPI phases of CMD and ADDR."]
     #[inline(always)]
     pub fn spi_fmem_dqs_ca_in(&self) -> SPI_FMEM_DQS_CA_IN_R {
-        SPI_FMEM_DQS_CA_IN_R::new(((self.bits >> 26) & 0x01) != 0)
+        SPI_FMEM_DQS_CA_IN_R::new(((self.bits >> 26) & 1) != 0)
     }
-    #[doc = "Bit 27 - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses flash or SPI1 accesses flash or sram."]
+    #[doc = "Bit 27 - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses to flash or SPI1 accesses flash or sram."]
     #[inline(always)]
     pub fn spi_fmem_hyperbus_dummy_2x(&self) -> SPI_FMEM_HYPERBUS_DUMMY_2X_R {
-        SPI_FMEM_HYPERBUS_DUMMY_2X_R::new(((self.bits >> 27) & 0x01) != 0)
+        SPI_FMEM_HYPERBUS_DUMMY_2X_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - Set this bit to invert SPI_DIFF when accesses to flash. ."]
     #[inline(always)]
     pub fn spi_fmem_clk_diff_inv(&self) -> SPI_FMEM_CLK_DIFF_INV_R {
-        SPI_FMEM_CLK_DIFF_INV_R::new(((self.bits >> 28) & 0x01) != 0)
+        SPI_FMEM_CLK_DIFF_INV_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - Set this bit to enable octa_ram address out when accesses to flash, which means ADDR_OUT\\[31:0\\]
  = {spi_usr_addr_value\\[25:4\\]
@@ -695,7 +779,7 @@ impl R {
 , 1'b0}."]
     #[inline(always)]
     pub fn spi_fmem_octa_ram_addr(&self) -> SPI_FMEM_OCTA_RAM_ADDR_R {
-        SPI_FMEM_OCTA_RAM_ADDR_R::new(((self.bits >> 29) & 0x01) != 0)
+        SPI_FMEM_OCTA_RAM_ADDR_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - Set this bit to enable HyperRAM address out when accesses to flash, which means ADDR_OUT\\[31:0\\]
  = {spi_usr_addr_value\\[19:4\\]
@@ -703,16 +787,16 @@ impl R {
 }."]
     #[inline(always)]
     pub fn spi_fmem_hyperbus_ca(&self) -> SPI_FMEM_HYPERBUS_CA_R {
-        SPI_FMEM_HYPERBUS_CA_R::new(((self.bits >> 30) & 0x01) != 0)
+        SPI_FMEM_HYPERBUS_CA_R::new(((self.bits >> 30) & 1) != 0)
     }
 }
 impl W {
-    #[doc = "Bit 0 - 1: in DDR mode, 0: in SDR mode."]
+    #[doc = "Bit 0 - 1: in ddr mode, 0 in sdr mode"]
     #[inline(always)]
     pub fn spi_fmem_ddr_en(&mut self) -> SPI_FMEM_DDR_EN_W {
         SPI_FMEM_DDR_EN_W { w: self }
     }
-    #[doc = "Bit 1 - Set the bit to enable variable dummy cycle in DDRmode."]
+    #[doc = "Bit 1 - Set the bit to enable variable dummy cycle in DDR mode."]
     #[inline(always)]
     pub fn spi_fmem_var_dummy(&mut self) -> SPI_FMEM_VAR_DUMMY_W {
         SPI_FMEM_VAR_DUMMY_W { w: self }
@@ -722,12 +806,12 @@ impl W {
     pub fn spi_fmem_ddr_rdat_swp(&mut self) -> SPI_FMEM_DDR_RDAT_SWP_W {
         SPI_FMEM_DDR_RDAT_SWP_W { w: self }
     }
-    #[doc = "Bit 3 - Set the bit to reorder TX data of the word in DDR mode."]
+    #[doc = "Bit 3 - Set the bit to swap TX data of a word in DDR mode."]
     #[inline(always)]
     pub fn spi_fmem_ddr_wdat_swp(&mut self) -> SPI_FMEM_DDR_WDAT_SWP_W {
         SPI_FMEM_DDR_WDAT_SWP_W { w: self }
     }
-    #[doc = "Bit 4 - the bit is used to disable dual edge in command phase when DDR mode."]
+    #[doc = "Bit 4 - the bit is used to disable dual edge in CMD phase when ddr mode."]
     #[inline(always)]
     pub fn spi_fmem_ddr_cmd_dis(&mut self) -> SPI_FMEM_DDR_CMD_DIS_W {
         SPI_FMEM_DDR_CMD_DIS_W { w: self }
@@ -737,6 +821,16 @@ impl W {
     pub fn spi_fmem_outminbytelen(&mut self) -> SPI_FMEM_OUTMINBYTELEN_W {
         SPI_FMEM_OUTMINBYTELEN_W { w: self }
     }
+    #[doc = "Bit 12 - Set this bit to mask the first or the last byte in MSPI ECC DDR write mode, when accesses to flash."]
+    #[inline(always)]
+    pub fn spi_fmem_tx_ddr_msk_en(&mut self) -> SPI_FMEM_TX_DDR_MSK_EN_W {
+        SPI_FMEM_TX_DDR_MSK_EN_W { w: self }
+    }
+    #[doc = "Bit 13 - Set this bit to mask the first or the last byte in MSPI ECC DDR read mode, when accesses to flash."]
+    #[inline(always)]
+    pub fn spi_fmem_rx_ddr_msk_en(&mut self) -> SPI_FMEM_RX_DDR_MSK_EN_W {
+        SPI_FMEM_RX_DDR_MSK_EN_W { w: self }
+    }
     #[doc = "Bits 14:20 - The delay number of data strobe which from memory based on SPI_CLK."]
     #[inline(always)]
     pub fn spi_fmem_usr_ddr_dqs_thd(&mut self) -> SPI_FMEM_USR_DDR_DQS_THD_W {
@@ -767,7 +861,7 @@ impl W {
     pub fn spi_fmem_dqs_ca_in(&mut self) -> SPI_FMEM_DQS_CA_IN_W {
         SPI_FMEM_DQS_CA_IN_W { w: self }
     }
-    #[doc = "Bit 27 - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses flash or SPI1 accesses flash or sram."]
+    #[doc = "Bit 27 - Set this bit to enable the vary dummy function in SPI HyperBus mode, when SPI0 accesses to flash or SPI1 accesses flash or sram."]
     #[inline(always)]
     pub fn spi_fmem_hyperbus_dummy_2x(&mut self) -> SPI_FMEM_HYPERBUS_DUMMY_2X_W {
         SPI_FMEM_HYPERBUS_DUMMY_2X_W { w: self }
@@ -800,7 +894,7 @@ impl W {
         self
     }
 }
-#[doc = "SPI1 DDR control register\n\nThis register you can [`read`]
+#[doc = "SPI0 flash DDR mode control register\n\nThis register you can [`read`]
 (crate::generic::Reg::read), [`write_with_zero`]
 (crate::generic::Reg::write_with_zero), [`reset`]
 (crate::generic::Reg::reset), [`write`]
@@ -822,10 +916,10 @@ impl crate::Readable for DDR_SPEC {
 impl crate::Writable for DDR_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets DDR to value 0x20"]
+#[doc = "`reset()` method sets DDR to value 0x3020"]
 impl crate::Resettable for DDR_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x20
+        0x3020
     }
 }
