@@ -317,102 +317,102 @@ impl R {
     #[doc = "Bit 0 - This interrupt raw bit turns to high level when receiver receives more data than what rxfifo_full_thrhd specifies."]
     #[inline(always)]
     pub fn rxfifo_full_int_raw(&self) -> RXFIFO_FULL_INT_RAW_R {
-        RXFIFO_FULL_INT_RAW_R::new((self.bits & 0x01) != 0)
+        RXFIFO_FULL_INT_RAW_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - This interrupt raw bit turns to high level when the amount of data in Tx-FIFO is less than what txfifo_empty_thrhd specifies ."]
     #[inline(always)]
     pub fn txfifo_empty_int_raw(&self) -> TXFIFO_EMPTY_INT_RAW_R {
-        TXFIFO_EMPTY_INT_RAW_R::new(((self.bits >> 1) & 0x01) != 0)
+        TXFIFO_EMPTY_INT_RAW_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - This interrupt raw bit turns to high level when receiver detects a parity error in the data."]
     #[inline(always)]
     pub fn parity_err_int_raw(&self) -> PARITY_ERR_INT_RAW_R {
-        PARITY_ERR_INT_RAW_R::new(((self.bits >> 2) & 0x01) != 0)
+        PARITY_ERR_INT_RAW_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - This interrupt raw bit turns to high level when receiver detects a data frame error ."]
     #[inline(always)]
     pub fn frm_err_int_raw(&self) -> FRM_ERR_INT_RAW_R {
-        FRM_ERR_INT_RAW_R::new(((self.bits >> 3) & 0x01) != 0)
+        FRM_ERR_INT_RAW_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - This interrupt raw bit turns to high level when receiver receives more data than the FIFO can store."]
     #[inline(always)]
     pub fn rxfifo_ovf_int_raw(&self) -> RXFIFO_OVF_INT_RAW_R {
-        RXFIFO_OVF_INT_RAW_R::new(((self.bits >> 4) & 0x01) != 0)
+        RXFIFO_OVF_INT_RAW_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - This interrupt raw bit turns to high level when receiver detects the edge change of DSRn signal."]
     #[inline(always)]
     pub fn dsr_chg_int_raw(&self) -> DSR_CHG_INT_RAW_R {
-        DSR_CHG_INT_RAW_R::new(((self.bits >> 5) & 0x01) != 0)
+        DSR_CHG_INT_RAW_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - This interrupt raw bit turns to high level when receiver detects the edge change of CTSn signal."]
     #[inline(always)]
     pub fn cts_chg_int_raw(&self) -> CTS_CHG_INT_RAW_R {
-        CTS_CHG_INT_RAW_R::new(((self.bits >> 6) & 0x01) != 0)
+        CTS_CHG_INT_RAW_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - This interrupt raw bit turns to high level when receiver detects a 0 after the stop bit."]
     #[inline(always)]
     pub fn brk_det_int_raw(&self) -> BRK_DET_INT_RAW_R {
-        BRK_DET_INT_RAW_R::new(((self.bits >> 7) & 0x01) != 0)
+        BRK_DET_INT_RAW_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - This interrupt raw bit turns to high level when receiver takes more time than rx_tout_thrhd to receive a byte."]
     #[inline(always)]
     pub fn rxfifo_tout_int_raw(&self) -> RXFIFO_TOUT_INT_RAW_R {
-        RXFIFO_TOUT_INT_RAW_R::new(((self.bits >> 8) & 0x01) != 0)
+        RXFIFO_TOUT_INT_RAW_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - This interrupt raw bit turns to high level when receiver recevies Xon char when uart_sw_flow_con_en is set to 1."]
     #[inline(always)]
     pub fn sw_xon_int_raw(&self) -> SW_XON_INT_RAW_R {
-        SW_XON_INT_RAW_R::new(((self.bits >> 9) & 0x01) != 0)
+        SW_XON_INT_RAW_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - This interrupt raw bit turns to high level when receiver receives Xoff char when uart_sw_flow_con_en is set to 1."]
     #[inline(always)]
     pub fn sw_xoff_int_raw(&self) -> SW_XOFF_INT_RAW_R {
-        SW_XOFF_INT_RAW_R::new(((self.bits >> 10) & 0x01) != 0)
+        SW_XOFF_INT_RAW_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - This interrupt raw bit turns to high level when receiver detects a glitch in the middle of a start bit."]
     #[inline(always)]
     pub fn glitch_det_int_raw(&self) -> GLITCH_DET_INT_RAW_R {
-        GLITCH_DET_INT_RAW_R::new(((self.bits >> 11) & 0x01) != 0)
+        GLITCH_DET_INT_RAW_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - This interrupt raw bit turns to high level when transmitter completes sending NULL characters, after all data in Tx-FIFO are sent."]
     #[inline(always)]
     pub fn tx_brk_done_int_raw(&self) -> TX_BRK_DONE_INT_RAW_R {
-        TX_BRK_DONE_INT_RAW_R::new(((self.bits >> 12) & 0x01) != 0)
+        TX_BRK_DONE_INT_RAW_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - This interrupt raw bit turns to high level when transmitter has kept the shortest duration after sending the last data."]
     #[inline(always)]
     pub fn tx_brk_idle_done_int_raw(&self) -> TX_BRK_IDLE_DONE_INT_RAW_R {
-        TX_BRK_IDLE_DONE_INT_RAW_R::new(((self.bits >> 13) & 0x01) != 0)
+        TX_BRK_IDLE_DONE_INT_RAW_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - This interrupt raw bit turns to high level when transmitter has send out all data in FIFO."]
     #[inline(always)]
     pub fn tx_done_int_raw(&self) -> TX_DONE_INT_RAW_R {
-        TX_DONE_INT_RAW_R::new(((self.bits >> 14) & 0x01) != 0)
+        TX_DONE_INT_RAW_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - This interrupt raw bit turns to high level when receiver detects a parity error from the echo of transmitter in rs485 mode."]
     #[inline(always)]
     pub fn rs485_parity_err_int_raw(&self) -> RS485_PARITY_ERR_INT_RAW_R {
-        RS485_PARITY_ERR_INT_RAW_R::new(((self.bits >> 15) & 0x01) != 0)
+        RS485_PARITY_ERR_INT_RAW_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - This interrupt raw bit turns to high level when receiver detects a data frame error from the echo of transmitter in rs485 mode."]
     #[inline(always)]
     pub fn rs485_frm_err_int_raw(&self) -> RS485_FRM_ERR_INT_RAW_R {
-        RS485_FRM_ERR_INT_RAW_R::new(((self.bits >> 16) & 0x01) != 0)
+        RS485_FRM_ERR_INT_RAW_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - This interrupt raw bit turns to high level when detects a clash between transmitter and receiver in rs485 mode."]
     #[inline(always)]
     pub fn rs485_clash_int_raw(&self) -> RS485_CLASH_INT_RAW_R {
-        RS485_CLASH_INT_RAW_R::new(((self.bits >> 17) & 0x01) != 0)
+        RS485_CLASH_INT_RAW_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - This interrupt raw bit turns to high level when receiver detects the configured at_cmd char."]
     #[inline(always)]
     pub fn at_cmd_char_det_int_raw(&self) -> AT_CMD_CHAR_DET_INT_RAW_R {
-        AT_CMD_CHAR_DET_INT_RAW_R::new(((self.bits >> 18) & 0x01) != 0)
+        AT_CMD_CHAR_DET_INT_RAW_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - This interrupt raw bit turns to high level when input rxd edge changes more times than what reg_active_threshold specifies in light sleeping mode."]
     #[inline(always)]
     pub fn wakeup_int_raw(&self) -> WAKEUP_INT_RAW_R {
-        WAKEUP_INT_RAW_R::new(((self.bits >> 19) & 0x01) != 0)
+        WAKEUP_INT_RAW_R::new(((self.bits >> 19) & 1) != 0)
     }
 }
 #[doc = "Raw interrupt status\n\nThis register you can [`read`]
